from .base_args import BaseArgs


class BatchItemsArgs(BaseArgs):
    """
    批量全网商品详情API接口：可同时获取20个商品的全网商品详情信息
    包含优惠券信息，可用来批量获取商品详情信息等超级功能。

    :doc http://www.zhetaoke.com/user/extend/extend_lingquan_detail_piliang.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10002/api/api_detail_piliang.ashx"

    num_iids: str
    """
    多个商品ID串，用英文逗号,分割，最大20个。
    该接口可以用来批量获取商品详情信息，包含优惠券信息、佣金信息等。
    该接口支持全网所有淘宝客商品。
    """

    def set_item_ids(self, ids: [str]):
        self.num_iids = ",".join(ids)



import json
import os
from dataclasses import dataclass

from .gen import AliSmsSync, SendSmsQueryParams, AliSmsBase


@dataclass
class TestConfig(object):
    access_key: str
    access_secret: str
    sign_name: str
    template_code: str
    mobile: str


def load_config() -> TestConfig:
    config_file = os.path.join(os.path.dirname(__file__), "..", "config.json")
    assert os.path.exists(config_file)

    with open(config_file) as fp:
        d = json.load(fp)
        return TestConfig(**d)


def test_str_signature():
    result = AliSmsBase.compute_str_signature("source", "secret")
    assert result == "Jv4yi8SobFhg5t1C7nWLbhBSFZQ="

    result = AliSmsBase.compute_str_signature("中文unicode", "secret")
    assert result == "szlfHs3WVaO/HgY3Cg7/uyXDaRw="


def test_send_sms():
    c = load_config()

    sms = AliSmsSync(access_key=c.access_key, access_secret=c.access_secret)
    query = SendSmsQueryParams(
        PhoneNumbers=c.mobile,
        SignName=c.sign_name,
        TemplateCode=c.template_code,
        TemplateParam=json.dumps({"code": "238672"}, separators=(",", ":")),
    )
    ret = sms.send_sms(query)
    assert ret is not None
    assert ret.Code == "OK"



from typing import List, Any

from pydantic import BaseModel, Field


class GaoYongContentItem(BaseModel):
    code: str = Field(None)
    type_one_id: str = Field(None)
    tao_id: str = Field(None)
    title: str = Field(None)
    jianjie: str = Field(None)
    pict_url: str = Field(None)
    user_type: str = Field(None)
    seller_id: str = Field(None)
    shop_dsr: str = Field(None)
    volume: str = Field(None)
    size: str = Field(None)
    quanhou_jiage: str = Field(None)
    date_time_yongjin: str = Field(None)
    tkrate3: str = Field(None)
    yongjin_type: str = Field(None)
    coupon_id: str = Field(None)
    coupon_start_time: str = Field(None)
    coupon_end_time: str = Field(None)
    coupon_info_money: str = Field(None)
    coupon_total_count: str = Field(None)
    coupon_remain_count: str = Field(None)
    coupon_info: str = Field(None)
    juhuasuan: str = Field(None)
    taoqianggou: str = Field(None)
    haitao: str = Field(None)
    jiyoujia: str = Field(None)
    jinpaimaijia: str = Field(None)
    pinpai: str = Field(None)
    pinpai_name: str = Field(None)
    yunfeixian: str = Field(None)
    nick: str = Field(None)
    small_images: str = Field(None)
    white_image: str = Field(None)
    tao_title: str = Field(None)
    provcity: str = Field(None)
    shop_title: str = Field(None)
    zhibo_url: str = Field(None)
    sellCount: str = Field(None)
    commentCount: str = Field(None)
    favcount: str = Field(None)
    score1: str = Field(None)
    score2: str = Field(None)
    score3: str = Field(None)
    creditLevel: str = Field(None)
    shopIcon: str = Field(None)
    pcDescContent: str = Field(None)
    taobao_url: str = Field(None)
    category_id: str = Field(None)
    category_name: str = Field(None)
    level_one_category_id: str = Field(None)
    level_one_category_name: str = Field(None)
    tkfee3: str = Field(None)
    biaoqian: str = Field(None)
    tag: str = Field(None)
    date_time: str = Field(None)
    presale_discount_fee_text: str = Field(None)
    presale_tail_end_time: str = Field(None)
    presale_tail_start_time: str = Field(None)
    presale_end_time: str = Field(None)
    presale_start_time: str = Field(None)
    presale_deposit: str = Field(None)
    min_commission_rate: str = Field(None)
    coupon_click_url: str = Field(None)
    item_url: str = Field(None)
    shorturl: str = Field(None)
    tkl: str = Field(None)


class GaoYongResp(BaseModel):
    status: int
    content: List[Any]



"""
折淘客开放平台 标准化的 API
"""
import json
from datetime import datetime
from typing import Optional, List

import aiohttp
import structlog

from .bang_dan_tui_jian_args import BangDanTuiJianArgs
from .batch_item_args import BatchItemsArgs
from .batch_item_resp import BatchItemResp, BatchItemContentItem
from .gao_yong_args import GaoYongArgs
from .gao_yong_resp import GaoYongResp, GaoYongContentItem
from .guess_you_like_args import GuessYouLikeArgs
from .ju_hua_suan_args import JuHuaSuanArgs
from .keyword_args import KeywordArgs
from .nine_nine_args import NineNineArgs
from .search_args import SearchArgs
from .suggest_args import SuggestArgs
from .tmall_chao_shi_args import TMallChaoShiArgs
from .tmall_shang_pin_args import TMallShangPinArgs
from ..tbk_api import TbkItemInfo

__all__ = ["ZTKStd"]


def to_std_time(s: Optional[str]) -> Optional[datetime]:
    try:
        return datetime.fromisoformat(s)
    except ValueError:
        return None


class ZTKStd(object):
    """
    标准版本的 淘宝客 API
    折淘客 开放平台 API
    """

    def __init__(self, ztk_sid: str, logger: structlog.stdlib.BoundLogger):
        """
        :param logger: 日志记录器
        """
        self._http: Optional[aiohttp.ClientSession] = None
        self._sid = ztk_sid
        self._logger = logger

    async def gao_yong(self, args: GaoYongArgs) -> Optional[TbkItemInfo]:
        """
        高佣转链标准化
        """
        url = await args.to_http_url()
        ret = await self._do_query(url)
        resp = GaoYongResp(**ret)
        if resp.status != 200:
            self._logger.error(f"request ztk {url=} failed with: {resp=}")
            return None
        if len(resp.content) == 0:
            self._logger.info(f"ztk not find: tao_id={args.num_iid}")
            return None

        item_list: List[GaoYongContentItem] = list(
            map(lambda x: GaoYongContentItem(**x), resp.content)
        )

        item = self._find_best_coupon_link(item_list)

        coupon_recv_num = int(item.coupon_total_count) - int(item.coupon_remain_count)

        return TbkItemInfo(
            tao_id=item.tao_id,
            tao_img=item.pict_url,
            tao_link=item.item_url,
            tao_details=item.pcDescContent.split("|"),
            title_short=item.title,
            title_long=item.tao_title,
            price_origin=float(item.size),
            price_actual=float(item.quanhou_jiage),
            price_coupon=float(item.coupon_info_money),
            seller_id=item.seller_id,
            seller_name=item.shop_title,
            seller_logo=item.shopIcon,
            score_dsr=float(item.score1),
            score_ship=float(item.score3),
            score_service=float(item.score2),
            commission_rate=float(item.tkrate3),
            commission_money=float(item.tkfee3),
            sale_month=int(item.volume),
            sale_day=0,
            sale_two_hours=0,
            coupon_start_time=to_std_time(item.coupon_start_time),
            coupon_end_time=to_std_time(item.coupon_end_time),
            coupon_total_num=int(item.coupon_total_count),
            coupon_recv_num=coupon_recv_num,
            coupon_link=item.coupon_click_url,
            yun_fei_xian=item.yunfeixian == "1",
        )

    async def bang_dan_tui_jian(
        self, args: BangDanTuiJianArgs
    ) -> Optional[List[TbkItemInfo]]:
        """
        全天销量榜API：返回24小时内销量榜单商品列表（前600个），返回佣金≥15%，动态描述分≥4.6的商品列表。
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def batch_items(self, args: BatchItemsArgs) -> BatchItemResp:
        """
        批量获取 淘宝 信息

        :param args:
        :return:
        """
        url = await args.to_http_url()
        j = await self._do_query(url)
        return BatchItemResp(**j)

    async def guess_you_like(
        self, args: GuessYouLikeArgs
    ) -> Optional[List[TbkItemInfo]]:
        """
        猜你喜欢
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def ju_hua_suan(self, args: JuHuaSuanArgs) -> Optional[List[TbkItemInfo]]:
        """
        聚划算商品API：返回聚划算商品列表，返回佣金≥15%，动态描述分≥4.6的商品列表。
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def keyword(self) -> List[str]:
        """
        关键词词典API
        """
        args = KeywordArgs()
        url = await args.to_http_url()
        j = await self._do_query(url)
        if isinstance(j, dict):
            if j["status"] == 200:
                content = j["content"]
                assert isinstance(content, list)
                return list(map(lambda x: x["keywords"], content))
        return []

    async def nine_nine(self, args: NineNineArgs) -> Optional[List[TbkItemInfo]]:
        """
        9.9元商品API：返回购买价格≤9.9元的商品列表，返回佣金≥15%，动态描述分≥4.6的商品列表。
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def search(self, args: SearchArgs) -> Optional[List[TbkItemInfo]]:
        """
        全网搜索
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def suggest(self, args: SuggestArgs) -> Optional[List[str]]:
        """
        联想词
        """
        url = await args.to_http_url()
        j = await self._do_query(url)
        if not isinstance(j, dict):
            self._logger.warn("request ztk suggest failed")
            return None

        result = j["result"]

        return list(map(lambda item: item[0], result))

    async def tmall_chao_shi(
        self, args: TMallChaoShiArgs
    ) -> Optional[List[TbkItemInfo]]:
        """
        天猫超市商品API：返回天猫超市商品列表，动态描述分≥4.6的商品列表，根据不同参数可返回天猫超市单件免邮商品。
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def tmall_shang_pin(
        self, args: TMallShangPinArgs
    ) -> Optional[List[TbkItemInfo]]:
        """
        天猫商品API：返回天猫商品列表，返回佣金≥15%，动态描述分≥4.6的商品列表。
        """
        url = await args.to_http_url()
        ret = await self._do_list_query_help(url)
        return ret

    async def _do_query(self, url: str) -> dict:
        if self._http is None:
            self._http = aiohttp.ClientSession()

        async with self._http.get(url) as result:
            text = await result.text()
            return json.loads(text)

    async def _ztk_sid(self) -> Optional[str]:
        """
        获取 折淘客的 sid
        """
        return self._sid

    async def _do_list_query_help(self, url: str) -> Optional[List[TbkItemInfo]]:
        ret = await self._do_query(url)
        if ret.get("status", None) != 200:
            self._logger.error(f"ztk fetch {url=} failed: {ret=}")
            return None
        content = ret.get("content", [])
        if len(content) < 1:
            self._logger.warning(f"ztk fetch {url=} without data")
            return []
        tao_ids = list(map(lambda x: x["tao_id"], content))
        return await self._do_fetch_batch_items(tao_ids)

    async def _do_fetch_batch_items(
        self, tao_ids: List[str]
    ) -> Optional[List[TbkItemInfo]]:
        args = BatchItemsArgs(num_iids=",".join(tao_ids))
        ret = await self.batch_items(args)
        if ret.status != 200:
            self._logger.error(f"ztk fetch batch item {args=} failed: {ret=}")
            return None
        data_list = map(lambda x: BatchItemContentItem(**x), ret.content)

        def convert_item_to_std(item: BatchItemContentItem) -> TbkItemInfo:
            #
            # http://www.zhetaoke.com/user/extend/extend_lingquan_detail.aspx
            #
            coupon_recv_num = int(item.coupon_total_count) - int(
                item.coupon_remain_count
            )

            return TbkItemInfo(
                tao_id=item.tao_id,
                tao_img=item.pict_url,
                tao_link=item.item_url,
                tao_details=item.pcDescContent.split("|"),
                title_short=item.title,
                title_long=item.tao_title,
                price_origin=float(item.size),
                price_actual=float(item.quanhou_jiage),
                price_coupon=float(item.coupon_info_money),
                seller_id=item.seller_id,
                seller_name=item.shop_title,
                seller_logo=item.shopIcon,
                score_dsr=float(item.score1),
                score_ship=float(item.score3),
                score_service=float(item.score2),
                commission_rate=float(item.tkrate3),
                commission_money=float(item.tkfee3),
                sale_month=int(item.volume),
                sale_day=0,
                sale_two_hours=0,
                coupon_start_time=to_std_time(item.coupon_start_time),
                coupon_end_time=to_std_time(item.coupon_end_time),
                coupon_total_num=int(item.coupon_total_count),
                coupon_recv_num=coupon_recv_num,
                coupon_link=None,
                yun_fei_xian=item.yunfeixian == "1",
            )

        return list(map(convert_item_to_std, data_list))

    @staticmethod
    def _find_best_coupon_link(
        coupon_links: List[GaoYongContentItem],
    ) -> GaoYongContentItem:
        """
        从高佣返回列表中找到佣金最高的
        :param coupon_links:
        :return:
        """
        if len(coupon_links) == 1:
            return coupon_links[0]

        best = coupon_links[0]

        for item in coupon_links[1:]:
            # 没有 优惠券
            if (
                item.coupon_click_url is None
                or item.coupon_click_url == ""
                or item.tkfee3 is None
            ):
                continue

            if (
                best.coupon_click_url is None  # 没有优惠URL
                or best.tkfee3 is None  # 没有佣金
                or best.tkfee3 < item.tkfee3  # 佣金小
            ):
                best = item
                continue

        return best



import base64
import hashlib
import json
import time
from typing import Optional

import requests
from pyDes import *  # noqa
from structlog.stdlib import BoundLogger

__all__ = ["MobSmsApi"]


class MobSmsApi(object):
    """
    掌淘科技 SMS 认证 API 接口
    """

    def __init__(self, logger: BoundLogger, app_key: str, app_secret: str):
        self._log = logger
        self._app_key = app_key
        self._app_secret = app_secret

    def sms_verify(
        self, mob_token: str, op_token: str, operator: str, md5: str
    ) -> Optional[str]:
        """
        sms token 认证

        :param mob_token:
        :param op_token:
        :param operator:
        :param md5: android md5 验证码
        :return: 成功返回手机号 失败返回 None
        """
        url = "http://identify.verify.mob.com/auth/auth/sdkClientFreeLogin"
        app_key = self._app_key

        data = {
            "appkey": app_key,
            "token": mob_token,
            "opToken": op_token,
            "operator": operator,
            "timestamp": int(time.time() * 1000),
            "md5": md5,
        }

        data["sign"] = self._generate_sign(data, self._app_secret)

        ret = requests.post(url, json=data)
        if not ret.ok:
            self._log.bind(ret=ret).error("request mob tech failed")
            return None

        ret = ret.json()

        if ret["status"] != 200:
            self._log.bind(data=ret).error("invalid status")
            return None

        k = des(  # noqa
            self._app_secret[:8], CBC, "00000000", pad=None, padmode=PAD_PKCS5  # noqa
        )
        b: bytes = k.decrypt(base64.b64decode(ret["res"]))
        # b'{"isValid":1,"phone":"18600825785","valid":true}'
        t = b.decode()
        d = json.loads(t)
        if d["isValid"] == 1:
            self._log.bind(data=d).info("mob ret success")
            return d["phone"]
        else:
            self._log.bind(data=d).error("mob tech check invalid")
            return None

    @staticmethod
    def _generate_sign(request: dict, secret: str) -> str:
        ret = ""
        stmp = sorted(request.items(), key=lambda d: d[0])
        for i in stmp:
            ret += i[0] + "=" + str(i[1]) + "&"
        return hashlib.md5((ret[:-1] + secret).encode("utf-8")).hexdigest()



from pydantic import BaseModel, Field

__all__ = ["TimeGetArgs"]


class TimeGetArgs(BaseModel):
    """
    获取淘宝系统当前时间

    doc: https://open.taobao.com/api.htm?docId=120&docType=2
    """

    method: str = Field("taobao.time.get")



from typing import Optional

from pydantic import Field, BaseModel

__all__ = ["TBKScPublisherInfoSaveResp"]


class TBKScPublisherInfoSaveResp(BaseModel):
    """
    淘宝客-公用-私域用户备案

    doc: https://open.taobao.com/api.htm?docId=37988&docType=2
    """

    account_name: str = Field(..., title="渠道昵称")
    desc: str = Field(..., title="如果重复绑定会提示：”重复绑定渠道“或”重复绑定粉丝“")
    relation_id: Optional[int] = Field(None, title="渠道关系ID")
    special_id: Optional[int] = Field(None, title="会员运营ID")



__all__ = ["TopHttpException", "TopErrorRespException"]


class TopHttpException(Exception):
    """
    网络错误/HTTP请求错误
    """

    def __init__(self, msg: str):
        super().__init__()
        self._msg = msg


class TopErrorRespException(Exception):
    """
    返回的结果错误 缺少权限等
    """

    def __init__(self, ret: dict):
        super().__init__()
        self._ret = ret



#
# this code is auto generated by other program
# DO NOT modify this
#

import json
from urllib import parse

import requests
from aiohttp import ClientSession

from .base import DtkBase
from .dt_resp_v2 import *


class DelsJdKitPromotionUnionConvertArgs(BaseModel):
    unionId: str = Field(..., title=f"""推客的联盟ID""")

    materialId: str = Field(..., title=f"""推广物料url，例如活动链接、商品链接等；不支持仅传入skuid""")

    positionId: Optional[str] = Field(
        None, title=f"""新增推广位id （不填的话，默认生成一个唯一此接口推广位-名称：微信手Q短链接"""
    )

    childPid: Optional[str] = Field(None, title=f""" 联盟子推客身份标识（不能传入接口调用者自己的pid）""")

    subUnionId: Optional[str] = Field(
        None, title=f"""子渠道标识，您可自定义传入字母、数字或下划线，最多支持80个字符，该参数会在订单行查询接口中展示"""
    )

    couponUrl: Optional[str] = Field(
        None, title=f"""优惠券领取链接，在使用优惠券、商品二合一功能时入参，且materialId须为商品详情页链接"""
    )

    chainType: Optional[str] = Field(
        None, title=f"""转链类型，默认短链，短链有效期60天1：长链2：短链 3：长链+短链，"""
    )

    giftCouponKey: Optional[str] = Field(None, title=f"""礼金批次号""")


class DelsJdOrderGetOfficialOrderListArgs(BaseModel):
    pageNo: Optional[str] = Field(None, title=f"""页码（默认为1）""")

    pageSize: Optional[str] = Field(None, title=f"""每页记录条数，默认100""")

    type: str = Field(..., title=f"""订单时间查询类型(1：下单时间，2：完成时间（购买用户确认收货时间），3：更新时间""")

    childUnionId: Optional[str] = Field(
        None, title=f"""子推客unionID，传入该值可查询子推客的订单，注意不可和key同时传入。（需联系运营开通PID权限才能拿到数据）"""
    )

    startTime: str = Field(
        ..., title=f"""开始时间 格式yyyy-MM-dd HH:mm:ss，与endTime间隔不超过1小时"""
    )

    endTime: str = Field(
        ..., title=f"""结束时间 格式yyyy-MM-dd HH:mm:ss，与startTime间隔不超过1小时"""
    )

    key: str = Field(
        ...,
        title=f"""工具商传入推客的授权key，可帮助该推客查询订单，注意不可和childUnionid同时传入。（需联系运营开通工具商权限才能拿到数据，请在京东联盟->我的工具->我的API->领取授权KEY中获取key）""",
    )


class GoodsGetHistoryLowPriceListArgs(BaseModel):
    pageSize: str = Field(..., title=f"""每页返回条数，每页条数支持输入10,20，50,100。默认50条""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    cids: Optional[str] = Field(
        None, title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。"""
    )

    sort: str = Field(
        ...,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )


class DelanysMediaVideoGetGoodsListArgs(BaseModel):
    cid: str = Field(..., title=f"""短视频分类id""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    pageSize: str = Field(..., title=f"""每页记录条数：10，20，50，100""")


class DelanysBrandGetGoodsListArgs(BaseModel):
    brandId: str = Field(..., title=f"""品牌id""")

    pageId: str = Field(
        ..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……） 第一页时会携带品牌信息数据"""
    )

    pageSize: str = Field(..., title=f"""每页记录条数（每页支持最大记录条数100）""")


class DelanysBrandGetColumnListArgs(BaseModel):
    cid: str = Field(..., title=f"""大淘客分类id""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    pageSize: str = Field(..., title=f""" 每页记录条数（每页记录最大支持50，如果参数大于50时取50作为每页记录条数）""")


class CommentGetCommentListArgs(BaseModel):
    id: str = Field(..., title=f"""大淘客商品id（id和goodsid其中一个必填）""")

    goodsId: Optional[str] = Field(None, title=f"""淘宝商品id（id和goodsid其中一个必填）""")

    type: Optional[str] = Field(None, title=f"""默认：0-全部  评论类型：0-全部；1-含图；2-含视频；""")


class DelsShopConvertArgs(BaseModel):
    sellerId: str = Field(..., title=f"""店铺id""")

    pid: str = Field(..., title=f"""推广位id""")

    relationId: Optional[str] = Field(None, title=f"""渠道id""")

    shopName: str = Field(..., title=f"""店铺名称，用于返回淘口令""")


class SubdivisionGetRankListArgs(BaseModel):
    subdivisionId: str = Field(..., title=f"""细分类目榜分类id（从商品详情获取）""")


class GoodsSuperDiscountGoodsArgs(BaseModel):
    pageSize: str = Field(..., title=f"""每页返回条数，每页条数支持输入10,20，50,100。默认50条""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    cids: Optional[str] = Field(
        None, title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。"""
    )

    sort: str = Field(
        ...,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )


class GoodsGetHalfPriceDayArgs(BaseModel):
    sessions: str = Field(..., title=f""" 默认为当前场次，场次输入格式，例如02、08、12、13""")


class DelsMergeRedEnvelopesArgs(BaseModel):
    merchantType: str = Field(..., title=f"""（1-淘宝红包，2京东红包，3-拼多多红包）""")

    pid: Optional[str] = Field(
        None,
        title=f"""推广位ID（大淘客账号下已授权淘宝账号的任一pid，若未填写，则默认使用创建应用时绑定的pid；其中京东pid为联盟子推客身份标识（不能传入接口调用者自己的pid）""",
    )

    unionId: str = Field(..., title=f"""选择京东红包时需要填入京东联盟ID（在京东联盟后台个人中心）。其他类型不用传""")


class GoodsPriceTrendArgs(BaseModel):
    id: str = Field(..., title=f"""在大淘客的在线商品id（已下架的商品id不支持）""")

    goodsId: Optional[str] = Field(None, title=f"""淘宝商品id""")


class GoodsLivematerialGoodsListArgs(BaseModel):
    date: Optional[str] = Field(
        None, title=f"""选择某一天的直播商品数据，默认返回全部参与过直播，且未下架的商品。时间格式：2020-09-16"""
    )

    sort: Optional[str] = Field(
        None,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )


class GoodsExplosiveGoodsListArgs(BaseModel):
    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    pageSize: str = Field(..., title=f"""每页返回条数，每页条数支持输入10,20，50,100。默认50条""")

    PriceCid: Optional[str] = Field(
        None, title=f"""价格区间，1表示10~20元区；2表示20~40元区；3表示40元以上区；默认为1"""
    )

    cids: Optional[str] = Field(
        None,
        title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。1 -女装，2 -母婴，3 -美妆，4 -居家日用，5 -鞋品，6 -美食，7 -文娱车品，8 -数码家电，9 -男装，10 -内衣，11 -箱包，12 -配饰，13 -户外运动，14 -家装家纺。不填默认全部""",
    )


class TbServiceParseContentArgs(BaseModel):
    content: str = Field(
        ...,
        title=f"""包含淘口令、链接的文本。优先解析淘口令，再按序解析每个链接，直至解出有效信息。*如果淘口令失效或者不支持的类型的情况，会按顺序解析链接。如果存在解析失败，请再试一次*""",
    )


class GoodsExclusiveGoodsListArgs(BaseModel):
    pageSize: str = Field(..., title=f"""每页返回条数，每页条数支持输入10,20，50,100。默认50条""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    cids: Optional[str] = Field(
        None, title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。"""
    )

    sort: Optional[str] = Field(
        None,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )


class TbServiceActivityLinkArgs(BaseModel):
    promotionSceneId: str = Field(
        ..., title=f"""联盟官方活动ID，从联盟官方活动页获取或从*大淘客官方活动推广接口获取*"""
    )

    pid: Optional[str] = Field(None, title=f"""推广pid，默认为在”我的应用“添加的pid""")

    relationId: Optional[str] = Field(
        None, title=f"""渠道id将会和传入的pid进行验证，验证通过将正常转链，请确认填入的渠道id是正确的"""
    )

    unionId: Optional[str] = Field(
        None, title=f"""自定义输入串，英文和数字组成，长度不能大于12个字符，区分不同的推广渠道"""
    )


class TbServiceTwdToTwdArgs(BaseModel):
    content: str = Field(..., title=f"""支持包含文本的淘口令，但最好是一个单独淘口令""")

    pid: Optional[str] = Field(
        None, title=f"""推广位ID，用户可自由填写当前大淘客账号下已授权淘宝账号的任一pid，若未填写，则默认使用创建应用时绑定的pid"""
    )

    channelId: Optional[str] = Field(
        None, title=f"""渠道id将会和传入的pid进行验证，验证通过将正常转链，请确认填入的渠道id是正确的"""
    )

    special_id: Optional[str] = Field(None, title=f"""会员运营ID""")

    external_id: Optional[str] = Field(None, title=f"""淘宝客外部用户标记，如自身系统账户ID；微信ID等""")


class GoodsFirstOrderGiftMoneyArgs(BaseModel):
    pageSize: str = Field(..., title=f"""每页返回条数，每页条数支持输入10,20，50,100,200""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    cids: Optional[str] = Field(
        None,
        title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。1 -女装，2 -母婴，3 -美妆，4 -居家日用，5 -鞋品，6 -美食，7 -文娱车品，8 -数码家电，9 -男装，10 -内衣，11 -箱包，12 -配饰，13 -户外运动，14 -家装家纺""",
    )

    sort: Optional[str] = Field(
        None,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    keyWord: Optional[str] = Field(None, title=f"""输入关键词搜索*(新增字段)*""")

    goodsType: Optional[str] = Field(
        None, title=f"""商品类型1表示大淘客商品2表示联盟商品。默认为1 *（2020.11.4新增字段）*"""
    )


class TbServiceCreatTaokoulingArgs(BaseModel):
    text: str = Field(..., title=f"""口令弹框内容，长度大于5个字符""")

    url: str = Field(
        ...,
        title=f"""口令跳转目标页，如：https://uland.taobao.com/，*必须以https开头*，可以是二合一链接、长链接、短链接等各种淘宝高佣链接；支持渠道备案链接。* 该参数需要进行Urlencode编码后传入*""",
    )

    logo: Optional[str] = Field(None, title=f"""口令弹框logoURL""")

    userId: Optional[str] = Field(None, title=f"""生成口令的淘宝用户ID，非必传参数""")


class TbServiceGetOrderDetailsArgs(BaseModel):
    positionIndex: Optional[str] = Field(
        None, title=f"""位点，第一页数据返回里面有个这个字段，查第二页的数据的时候就传过去"""
    )

    pageSize: Optional[str] = Field(None, title=f"""页大小，默认20，1~100""")

    memberType: Optional[str] = Field(None, title=f"""推广者角色类型,2:二方，3:三方，不传，表示所有角色""")

    tkStatus: Optional[str] = Field(
        None, title=f"""淘客订单状态，12-付款，13-关闭，14-确认收货，3-结算成功;不传，表示所有状态"""
    )

    endTime: str = Field(
        ...,
        title=f"""订单查询结束时间，订单开始时间至订单结束时间，*中间时间段日常要求不超过3个小时，但如618、双11、年货节等大促期间预估时间段不可超过20分钟，超过会提示错误，调用时请务必注意时间段的选择，以保证亲能正常调用！*  时间格式：YYYY-MM-DD HH:MM:SS""",
    )

    startTime: str = Field(..., title=f"""订单查询开始时间。时间格式：YYYY-MM-DD HH:MM:SS""")

    jumpType: Optional[str] = Field(
        None, title=f"""跳转类型，当向前或者向后翻页必须提供,-1: 向前翻页,1：向后翻页"""
    )

    pageNo: Optional[str] = Field(None, title=f"""第几页，默认1，1~100""")

    orderScene: Optional[str] = Field(
        None, title=f"""场景订单场景类型，1:常规订单，2:渠道订单，3:会员运营订单，默认为1"""
    )

    queryType: str = Field(
        ..., title=f"""查询时间类型，1：按照订单淘客创建时间查询，2:按照订单淘客付款时间查询，3:按照订单淘客结算时间查询"""
    )


class TbServiceParseTaokoulingArgs(BaseModel):
    content: str = Field(
        ..., title=f"""包含淘口令的文本。* 若文本中有多个淘口令，仅解析第一个。（目前仅支持商品口令和二合一券口令）* """
    )


class TbServiceGetPrivilegeLinkArgs(BaseModel):
    goodsId: str = Field(..., title=f"""淘宝商品id""")

    couponId: Optional[str] = Field(
        None,
        title=f"""商品的优惠券ID，一个商品在联盟可能有多个优惠券，可通过填写该参数的方式选择使用的优惠券，请确认优惠券ID正确，否则无法正常跳转""",
    )

    pid: Optional[str] = Field(
        None, title=f"""推广位ID，用户可自由填写当前大淘客账号下已授权淘宝账号的任一pid，若未填写，则默认使用创建应用时绑定的pid"""
    )

    channelId: Optional[str] = Field(
        None,
        title=f"""渠道id将会和传入的pid进行验证，验证通过将正常转链，请确认填入的渠道id是正确的 *channelId对应联盟的relationId*""",
    )

    specialId: Optional[str] = Field(None, title=f"""会员运营id""")

    externalId: Optional[str] = Field(None, title=f"""淘宝客外部用户标记，如自身系统账户ID；微信ID等""")

    rebateType: Optional[str] = Field(None, title=f"""付定返红包，0.不使用付定返红包，1.参与付定返红包""")


class GoodsNineOpGoodsListArgs(BaseModel):
    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    pageSize: str = Field(..., title=f"""每页条数：默认为20，最大值100""")

    nineCid: str = Field(
        ..., title=f"""9.9精选的类目id，分类id请求详情：*-1-精选，1 -5.9元区，2 -9.9元区，3 -19.9元区（调整字段）*"""
    )


class CategoryDdqGoodsListArgs(BaseModel):
    roundTime: Optional[str] = Field(
        None, title=f"""默认为当前场次，场次时间输入方式：yyyy-mm-dd hh:mm:ss"""
    )


class GoodsGetRankingListArgs(BaseModel):
    rankType: str = Field(
        ..., title=f"""榜单类型，1.实时榜 2.全天榜 3.热推榜 4.复购榜 5.热词飙升榜 6.热词排行榜 7.综合热搜榜"""
    )

    cid: Optional[str] = Field(None, title=f"""大淘客一级类目id，仅对实时榜单、全天榜单有效""")

    pageSize: Optional[str] = Field(None, title=f"""每页条数返回条数（支持10,20.50，默认返回20条）""")

    pageId: Optional[str] = Field(
        None, title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）。*超过200条，分页返回为空*"""
    )


class GoodsFriendsCircleListArgs(BaseModel):
    pageSize: Optional[str] = Field(
        None, title=f"""每页条数，默认为100，若小于10，则按10条处理，每页条数仅支持输入10,50,100"""
    )

    pageId: str = Field(..., title=f"""分页id，默认为1，支持传统的页码分页方式""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    subcid: Optional[str] = Field(
        None,
        title=f"""大淘客的二级类目id，通过超级分类API获取。仅允许传一个二级id，当一级类目id和二级类目id同时传入时，会自动忽略二级类目id""",
    )

    pre: Optional[str] = Field(None, title=f"""是否预告商品，1-预告商品，0-所有商品，不填默认为0""")

    freeshipRemoteDistrict: Optional[str] = Field(
        None, title=f"""偏远地区包邮，1-是，0-非偏远地区，不填默认所有商品"""
    )

    goodsId: Optional[str] = Field(
        None, title=f"""大淘客id或淘宝id，查询单个商品是否有朋友圈文案，如果有，则返回商品信息及朋友圈文案，如果没有，显示10006错误 """
    )

    cid: Optional[str] = Field(None, title=f"""大淘客的一级分类id，如6、4""")


class GoodsTopicGoodsListArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口第一次返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入库商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: Optional[str] = Field(None, title=f"""每页条数，默认为100，大于100按100处理""")

    topicId: str = Field(..., title=f"""专辑id，通过精选专辑API获取的活动id""")


class CategoryGetTbTopicListArgs(BaseModel):
    pageId: str = Field(..., title=f"""分页id，支持传统的页码分页方式""")

    pageSize: Optional[str] = Field(None, title=f"""每页条数，默认为20""")

    type: Optional[str] = Field(None, title=f"""输出的端口类型：0.全部（默认），1.PC，2.无线""")

    channelID: Optional[str] = Field(None, title=f"""阿里妈妈上申请的渠道id""")


class TbServiceGetBrandListArgs(BaseModel):
    pageId: str = Field(..., title=f"""页码""")

    pageSize: Optional[str] = Field(None, title=f"""每页条数，默认为20，最大值100""")


class GoodsSearchSuggestionArgs(BaseModel):
    keyWords: str = Field(..., title=f"""关键词""")

    type: str = Field(..., title=f"""当前搜索API类型：1.大淘客搜索 2.联盟搜索 3.超级搜索""")


class GoodsListSuperGoodsArgs(BaseModel):
    pageId: str = Field(..., title=f"""请求的页码，默认参数1""")

    pageSize: str = Field(..., title=f"""每页条数，默认为20，最大值100""")

    keyWords: str = Field(..., title=f"""关键词搜索""")

    type: str = Field(..., title=f"""搜索类型：0-综合结果，1-大淘客商品，2-联盟商品""")

    tmall: Optional[str] = Field(None, title=f"""是否天猫商品：1-天猫商品，0-所有商品，不填默认为0""")

    haitao: Optional[str] = Field(None, title=f"""是否海淘商品：1-海淘商品，0-所有商品，不填默认为0""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序字段信息 销量（total_sales） 价格（price），排序_des（降序），排序_asc（升序），示例：升序查询销量total_sales_asc""",
    )

    specialId: Optional[str] = Field(None, title=f"""会员运营id""")

    channelId: Optional[str] = Field(
        None,
        title=f"""渠道id将会和传入的pid进行验证，验证通过将正常转链，请确认填入的渠道id是正确的*channelId对应联盟的relationId*""",
    )


class GoodsListSimilerGoodsByOpenArgs(BaseModel):
    id: str = Field(..., title=f"""大淘客的商品id""")

    size: Optional[str] = Field(None, title=f"""每页条数，默认10 ， 最大值100""")


class GoodsGetGoodsListArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: Optional[str] = Field(
        None, title=f"""每页条数，默认为100，最大值200，若小于10，则按10条处理，每页条数仅支持输入10,50,100,200"""
    )

    sort: Optional[str] = Field(
        None,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    cids: Optional[str] = Field(
        None,
        title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。当一级类目id和二级类目id同时传入时，会自动忽略二级类目id""",
    )

    subcid: Optional[str] = Field(
        None,
        title=f"""大淘客的二级类目id，通过超级分类API获取。仅允许传一个二级id，当一级类目id和二级类目id同时传入时，会自动忽略二级类目id""",
    )

    juHuaSuan: Optional[str] = Field(None, title=f"""1-聚划算商品，0-所有商品，不填默认为0""")

    taoQiangGou: Optional[str] = Field(None, title=f"""1-淘抢购商品，0-所有商品，不填默认为0""")

    tmall: Optional[str] = Field(None, title=f"""1-天猫商品， 0-非天猫商品，不填默认所有商品""")

    tchaoshi: Optional[str] = Field(None, title=f"""1-天猫超市商品， 0-所有商品，不填默认为0""")

    goldSeller: Optional[str] = Field(None, title=f"""1-金牌卖家商品，0-所有商品，不填默认为0""")

    haitao: Optional[str] = Field(None, title=f"""1-海淘商品， 0-所有商品，不填默认为0""")

    pre: Optional[str] = Field(None, title=f"""1-预告商品，0-所有商品，不填默认为0""")

    brand: Optional[str] = Field(None, title=f"""1-品牌商品，0-所有商品，不填默认为0""")

    brandIds: Optional[str] = Field(
        None,
        title=f"""当brand传入0时，再传入brandIds可能无法获取结果。品牌id可以传多个，以英文逗号隔开，如：”345,321,323”""",
    )

    priceLowerLimit: Optional[str] = Field(None, title=f"""价格（券后价）下限""")

    priceUpperLimit: Optional[str] = Field(None, title=f"""价格（券后价）上限""")

    commissionRateLowerLimit: Optional[str] = Field(None, title=f"""最低佣金比率""")

    monthSalesLowerLimit: Optional[str] = Field(None, title=f"""最低月销量""")

    specialId: Optional[str] = Field(
        None, title=f"""商品卖点，1.拍多件活动；2.多买多送；3.限量抢购；4.额外满减；6.买商品礼赠"""
    )

    freeshipRemoteDistrict: Optional[str] = Field(
        None, title=f"""偏远地区包邮，1-是，0-非偏远地区，不填默认所有商品"""
    )

    couponPriceLowerLimit: Optional[str] = Field(None, title=f"""最低优惠券面额""")

    preSale: Optional[str] = Field(
        None, title=f"""1-活动预售商品，0-所有商品，不填默认为0。*（10.30新增字段）*"""
    )


class GoodsGetGoodsDetailsArgs(BaseModel):
    id: str = Field(..., title=f"""大淘客商品id，请求时id或goodsId必填其中一个，若均填写，将优先查找当前单品id""")

    goodsId: Optional[str] = Field(
        None, title=f"""淘宝商品id，id或goodsId必填其中一个，若均填写，将优先查找当前单品id"""
    )


class GoodsGetDtkSearchGoodsArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: str = Field(
        ..., title=f"""每页条数，默认为100，最大值200，若小于10，则按10条处理，每页条数仅支持输入10,50,100,200"""
    )

    keyWords: str = Field(..., title=f"""关键词搜索""")

    cids: Optional[str] = Field(
        None,
        title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。当一级类目id和二级类目id同时传入时，会自动忽略二级类目id，一级分类id请求详情：1 -女装，2 -母婴，3 -美妆，4 -居家日用，5 -鞋品，6 -美食，7 -文娱车品，8 -数码家电，9 -男装，10 -内衣，11 -箱包，12 -配饰，13 -户外运动，14 -家装家纺""",
    )

    subcid: Optional[str] = Field(
        None,
        title=f"""大淘客的二级类目id，通过超级分类API获取。仅允许传一个二级id，当一级类目id和二级类目id同时传入时，会自动忽略二级类目id""",
    )

    juHuaSuan: Optional[str] = Field(None, title=f"""是否聚划算，1-聚划算商品，0-所有商品，不填默认为0""")

    taoQiangGou: Optional[str] = Field(None, title=f"""是否淘抢购，1-淘抢购商品，0-所有商品，不填默认为0""")

    tmall: Optional[str] = Field(None, title=f"""是否天猫商品，1-天猫商品，0-非天猫商品，不填默认为所有商品""")

    tchaoshi: Optional[str] = Field(None, title=f"""是否天猫超市商品，1-天猫超市商品，0-所有商品，不填默认为0""")

    goldSeller: Optional[str] = Field(None, title=f"""是否金牌卖家，1-金牌卖家，0-所有商品，不填默认为0""")

    haitao: Optional[str] = Field(None, title=f"""是否海淘商品，1-海淘商品，0-所有商品，不填默认为0""")

    brand: Optional[str] = Field(None, title=f"""是否品牌商品，1-品牌商品，0-所有商品，不填默认为0""")

    brandIds: Optional[str] = Field(
        None,
        title=f"""品牌id，当brand传入0时，再传入brandIds将获取不到结果。品牌id可以传多个，以英文逗号隔开，如：”345,321,323”""",
    )

    priceLowerLimit: Optional[str] = Field(None, title=f"""价格（券后价）下限""")

    priceUpperLimit: Optional[str] = Field(None, title=f"""价格（券后价）上限""")

    commissionRateLowerLimit: Optional[str] = Field(None, title=f"""最低佣金比率""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序字段，默认为0，0-综合排序，1-商品上架时间从新到旧，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    freeshipRemoteDistrict: Optional[str] = Field(
        None, title=f"""偏远地区包邮，1-是，0-非偏远地区，不填默认所有商品"""
    )

    couponPriceLowerLimit: Optional[str] = Field(None, title=f"""最低优惠券面额""")

    monthSalesLowerLimit: Optional[str] = Field(None, title=f"""最低月销量""")


class GoodsPullGoodsByTimeArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: Optional[str] = Field(
        None, title=f"""每页条数，默认为100，最大值200，若小于10，则按10条处理，每页条数仅支持输入10,50,100,200"""
    )

    cid: Optional[str] = Field(
        None, title=f"""大淘客的一级分类id。当一级类目id和二级类目id同时传入时，会自动忽略二级类目id"""
    )

    subcid: Optional[str] = Field(
        None,
        title=f"""大淘客的二级类目id，通过超级分类API获取。仅允许传一个二级id，当一级类目id和二级类目id同时传入时，会自动忽略二级类目id""",
    )

    pre: Optional[str] = Field(None, title=f"""是否预告商品，1-预告商品，0-所有商品，不填默认为0""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序方式，默认为0，0-综合排序，1-商品上架时间从新到旧，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    startTime: Optional[str] = Field(
        None, title=f"""开始时间，格式为yy-mm-dd hh:mm:ss，商品下架的时间大于等于开始时间"""
    )

    endTime: Optional[str] = Field(None, title=f"""结束时间，默认为请求的时间，商品下架的时间小于等于结束时间""")

    freeshipRemoteDistrict: Optional[str] = Field(
        None, title=f"""偏远地区包邮，1-是，0-非偏远地区，不填默认所有商品"""
    )


class GoodsGetStaleGoodsByTimeArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: Optional[str] = Field(None, title=f"""""")

    startTime: Optional[str] = Field(None, title=f"""""")

    endTime: Optional[str] = Field(
        None, title=f"""结束时间，默认为请求的时间，商品下架的时间小于等于结束时间，结束时间需要在当日"""
    )


class GoodsGetNewestGoodsArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: str = Field(
        ..., title=f"""每页条数，默认为100，最大值200，若小于10，则按10条处理，每页条数仅支持输入10,50,100,200"""
    )

    startTime: Optional[str] = Field(
        None, title=f"""商品上架开始时间，请求格式：yyyy-MM-dd HH:mm:ss"""
    )

    endTime: Optional[str] = Field(None, title=f"""商品上架结束时间，请求格式：yyyy-MM-dd HH:mm:ss""")

    cids: Optional[str] = Field(
        None,
        title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。当一级类目id和二级类目id同时传入时，会自动忽略二级类目id，1 -女装，2 -母婴，3 -美妆，4 -居家日用，5 -鞋品，6 -美食，7 -文娱车品，8 -数码家电，9 -男装，10 -内衣，11 -箱包，12 -配饰，13 -户外运动，14 -家装家纺""",
    )

    subcid: Optional[str] = Field(
        None,
        title=f"""大淘客的二级类目id，通过超级分类API获取。仅允许传一个二级id，当一级类目id和二级类目id同时传入时，会自动忽略二级类目id""",
    )

    juHuaSuan: Optional[str] = Field(None, title=f"""1-聚划算商品，0-所有商品，不填默认为0""")

    taoQiangGou: Optional[str] = Field(None, title=f"""1-淘抢购商品，0-所有商品，不填默认为0""")

    tmall: Optional[str] = Field(None, title=f"""1-天猫商品，0-非天猫商品，不填默认全部商品""")

    tchaoshi: Optional[str] = Field(None, title=f"""1-天猫超市商品，0-所有商品，不填默认为0""")

    goldSeller: Optional[str] = Field(None, title=f"""1-金牌卖家，0-所有商品，不填默认为0""")

    haitao: Optional[str] = Field(None, title=f"""1-海淘，0-所有商品，不填默认为0""")

    brand: Optional[str] = Field(None, title=f"""1-品牌，0-所有商品，不填默认为0""")

    brandIds: Optional[str] = Field(
        None,
        title=f"""品牌id，当brand传入0时，再传入brandIds将获取不到结果。品牌id可以传多个，以英文逗号隔开，如：”345,321,323”""",
    )

    priceLowerLimit: Optional[str] = Field(None, title=f"""价格（券后价）下限""")

    priceUpperLimit: Optional[str] = Field(None, title=f"""价格（券后价）上限""")

    couponPriceLowerLimit: Optional[str] = Field(None, title=f"""最低优惠券面额""")

    commissionRateLowerLimit: Optional[str] = Field(None, title=f"""最低佣金比率""")

    monthSalesLowerLimit: Optional[str] = Field(None, title=f"""最低月销量""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序字段，默认为0，0-综合排序，1-商品上架时间从新到旧，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    preSale: Optional[str] = Field(
        None, title=f"""1-活动预售商品，0-所有商品，不填默认为0。*（2020.10.30号新增字段）*"""
    )


class TbServiceGetTbServiceArgs(BaseModel):
    pageNo: str = Field(..., title=f"""第几页，默认1""")

    pageSize: str = Field(..., title=f"""每页条数， 默认20，范围值1~100""")

    keyWords: str = Field(..., title=f"""查询词""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序指标：销量（total_sales），淘客佣金比率（tk_rate）， 累计推广量（tk_total_sales），总支出佣金（tk_total_commi），价格（price）,排序方式：排序_des（降序），排序_asc（升序）,示例：升序查询销量：total_sales_asc""",
    )

    source: Optional[str] = Field(
        None,
        title=f"""是否商城商品，设置为1表示该商品是属于淘宝商城商品，设置为非1或不设置表示不判断这个属性（和overseas字段冲突，若已请求source，请勿再请求overseas）""",
    )

    overseas: Optional[str] = Field(
        None,
        title=f"""是否海外商品，设置为1表示该商品是属于海外商品，设置为非1或不设置表示不判断这个属性（和source字段冲突，若已请求overseas，请勿再请求source）""",
    )

    endPrice: Optional[str] = Field(None, title=f"""折扣价范围上限，单位：元""")

    startPrice: Optional[str] = Field(None, title=f"""折扣价范围下限，单位：元""")

    startTkRate: Optional[str] = Field(None, title=f"""媒体淘客佣金比率下限，如：1234表示12.34%""")

    endTkRate: Optional[str] = Field(None, title=f"""商品筛选-淘客佣金比率上限，如：1234表示12.34%""")

    hasCoupon: Optional[str] = Field(
        None, title=f"""是否有优惠券，设置为true表示该商品有优惠券，设置为false或不设置表示不判断这个属性"""
    )

    specialId: Optional[str] = Field(None, title=f"""会员运营id""")

    channelId: Optional[str] = Field(
        None,
        title=f"""渠道id将会和传入的pid进行验证，验证通过将正常转链，请确认填入的渠道id是正确的*channelId对应联盟的relationId*""",
    )


class GoodsGetCollectionListArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: Optional[str] = Field(
        None, title=f"""每页条数，默认为100，最大值200，若小于10，则按10条处理，每页条数仅支持输入10,50,100,200"""
    )

    cid: Optional[str] = Field(
        None,
        title=f"""商品在大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。当一级类目id和二级类目id同时传入时，会自动忽略二级类目id，1 -女装，2 -母婴，3 -美妆，4 -居家日用，5 -鞋品，6 -美食，7 -文娱车品，8 -数码家电，9 -男装，10 -内衣，11 -箱包，12 -配饰，13 -户外运动，14 -家装家纺""",
    )

    trailerType: Optional[str] = Field(
        None, title=f"""是否返回预告商品，1为预告商品，0为在线商品，不填则全部商品"""
    )

    sort: Optional[str] = Field(
        None,
        title=f"""排序字段，默认为0，0-综合排序，1-商品上架时间从高到低，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )

    collectionTimeOrder: Optional[str] = Field(None, title=f"""加入收藏时间""")


class GoodsGetOwnerGoodsArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入口商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: str = Field(
        ..., title=f"""每页条数，默认为100，最大值200，若小于10，则按10条处理，每页条数仅支持输入10,50,100,200"""
    )

    online: Optional[str] = Field(None, title=f"""是否下架，默认为1,1-未下架商品，0-已下架商品""")

    startTime: Optional[str] = Field(
        None, title=f"""商品提交开始时间，请求格式：yyyy-MM-dd HH:mm:ss"""
    )

    endTime: Optional[str] = Field(None, title=f"""商品上架结束时间，请求格式：yyyy-MM-dd HH:mm:ss""")

    sort: Optional[str] = Field(
        None,
        title=f"""排序字段，默认为0，0-综合排序，1-商品上架时间从新到旧，2-销量从高到低，3-领券量从高到低，4-佣金比例从高到低，5-价格（券后价）从高到低，6-价格（券后价）从低到高""",
    )


class GoodsActivityGoodsListArgs(BaseModel):
    pageId: str = Field(
        ...,
        title=f"""分页id，默认为1，支持传统的页码分页方式和scroll_id分页方式，根据用户自身需求传入值。示例1：商品入库，则首次传入1，后续传入接口第一次返回的pageid，接口将持续返回符合条件的完整商品列表，该方式可以避免入库商品重复；示例2：根据pagesize和totalNum计算出总页数，按照需求返回指定页的商品（该方式可能在临近页取到重复商品）""",
    )

    pageSize: Optional[str] = Field(None, title=f"""每页条数，默认为100，大于100按100处理""")

    activityId: str = Field(..., title=f"""通过热门活动API获取的活动id""")

    cid: Optional[str] = Field(
        None,
        title=f"""大淘客一级分类ID：1 -女装，2 -母婴，3 -美妆，4 -居家日用，5 -鞋品，6 -美食，7 -文娱车品，8 -数码家电，9 -男装，10 -内衣，11 -箱包，12 -配饰，13 -户外运动，14 -家装家纺""",
    )

    subcid: Optional[str] = Field(
        None, title=f"""大淘客二级分类ID：可通过超级分类接口获取二级分类id，当同时传入一级分类id和二级分类id时，以一级分类id为准"""
    )

    freeshipRemoteDistrict: Optional[str] = Field(None, title=f"""偏远地区包邮：1.是，0.否""")


class GoodsJdOneDollarPurchaseArgs(BaseModel):
    pageSize: str = Field(..., title=f"""每页返回条数，每页条数支持输入10,20，50,100。默认50条""")

    pageId: str = Field(..., title=f"""分页id：常规分页方式，请直接传入对应页码（比如：1,2,3……）""")

    cids: Optional[str] = Field(
        None, title=f"""大淘客的一级分类id，如果需要传多个，以英文逗号相隔，如：”1,2,3”。"""
    )

    sort: str = Field(..., title=f"""排序方式，默认为0，0-综合排序，5-价格（券后价）从高到低，6-价格（券后价）从低到高""")

    subsidy: Optional[str] = Field(None, title=f"""礼金类型（3-三元区；5-五元区）默认为三元区*（新增字段）*""")


class DelsJdOrderOuterGetOrderListArgs(BaseModel):
    orderTimeType: str = Field(
        ..., title=f"""订单时间类型：(1：下单时间，2：完成时间（购买用户确认收货时间），3：更新时间"""
    )

    startTime: str = Field(
        ..., title=f"""开始时间 格式yyyy-MM-dd HH:mm:ss，与endTime间隔不超过30天"""
    )

    endTime: str = Field(
        ..., title=f"""结束时间 格式yyyy-MM-dd HH:mm:ss，与startTime间隔不超过30天"""
    )

    pageId: Optional[str] = Field(None, title=f"""分页id，默认为1，支持scroll翻页查询""")

    pageSize: Optional[str] = Field(None, title=f"""每页记录条数，最大支持200""")

    code: Optional[str] = Field(None, title=f"""自定义标识，用于区分下游推广渠道*（如果没有做代理返利模式，可不传）*""")


class DelsJdKitOuterPromotionUnionConvertArgs(BaseModel):
    code: str = Field(..., title=f"""自定义标识，用于区分下游推广渠道。*只能由数字和字符串组成且字符串长度在5-16之间*""")

    materialId: str = Field(..., title=f"""使用【京东一元购】接口返回的*jumpURL*字段""")

    chainType: Optional[str] = Field(
        None, title=f"""转链类型，默认短链，短链有效期60天       1：长链2：短链3：长链+短链"""
    )


class DtkSync(DtkBase):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._session = requests.Session()

    def _do_request(self, url: str, version: str, merge_args: dict) -> Optional[dict]:
        data = self.merge_args(merge_args, version)
        query = parse.urlencode(data)
        resp: requests.Response = self._session.get(f"{url}?{query}")
        if resp.ok:
            return resp.json()
        return None

    def dels_jd_kit_promotion_union_convert(
        self, args: DelsJdKitPromotionUnionConvertArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=52
        """
        url = "https://openapi.dataoke.com/api/dels/jd/kit/promotion-union-convert"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def dels_jd_order_get_official_order_list(
        self, args: DelsJdOrderGetOfficialOrderListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=51
        """
        url = "https://openapi.dataoke.com/api/dels/jd/order/get-official-order-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_get_history_low_price_list(
        self, args: GoodsGetHistoryLowPriceListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=48
        """
        url = "https://openapi.dataoke.com/api/goods/get-history-low-price-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def delanys_media_video_get_goods_list(
        self, args: DelanysMediaVideoGetGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=46
        """
        url = "https://openapi.dataoke.com/api/delanys/media/video/get-goods-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def delanys_media_video_get_category_list(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=47
        """
        url = "https://openapi.dataoke.com/api/delanys/media/video/get-category-list"
        version = "v1.0.0"
        return self._do_request(url, version, dict())

    def delanys_brand_get_goods_list(
        self, args: DelanysBrandGetGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=45
        """
        url = "https://openapi.dataoke.com/api/delanys/brand/get-goods-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def delanys_brand_get_column_list(
        self, args: DelanysBrandGetColumnListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=44
        """
        url = "https://openapi.dataoke.com/api/delanys/brand/get-column-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def comment_get_comment_list(
        self, args: CommentGetCommentListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=43
        """
        url = "https://openapi.dataoke.com/api/comment/get-comment-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def dels_shop_convert(self, args: DelsShopConvertArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=42
        """
        url = "https://openapi.dataoke.com/api/dels/shop/convert"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def subdivision_get_rank_list(
        self, args: SubdivisionGetRankListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=41
        """
        url = "https://openapi.dataoke.com/api/subdivision/get-rank-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_super_discount_goods(
        self, args: GoodsSuperDiscountGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=39
        """
        url = "https://openapi.dataoke.com/api/goods/super-discount-goods"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_get_half_price_day(
        self, args: GoodsGetHalfPriceDayArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=38
        """
        url = "https://openapi.dataoke.com/api/goods/get-half-price-day"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def dels_merge_red_envelopes(
        self, args: DelsMergeRedEnvelopesArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=37
        """
        url = "https://openapi.dataoke.com/api/dels/merge-red-envelopes"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_price_trend(self, args: GoodsPriceTrendArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=36
        """
        url = "https://openapi.dataoke.com/api/goods/price-trend"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_liveMaterial_goods_list(
        self, args: GoodsLivematerialGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=35
        """
        url = "https://openapi.dataoke.com/api/goods/liveMaterial-goods-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_explosive_goods_list(
        self, args: GoodsExplosiveGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=34
        """
        url = "https://openapi.dataoke.com/api/goods/explosive-goods-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def tb_service_parse_content(
        self, args: TbServiceParseContentArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=33
        """
        url = "https://openapi.dataoke.com/api/tb-service/parse-content"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_exclusive_goods_list(
        self, args: GoodsExclusiveGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=32
        """
        url = "https://openapi.dataoke.com/api/goods/exclusive-goods-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def tb_service_activity_link(
        self, args: TbServiceActivityLinkArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=31
        """
        url = "https://openapi.dataoke.com/api/tb-service/activity-link"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def tb_service_twd_to_twd(self, args: TbServiceTwdToTwdArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=30
        """
        url = "https://openapi.dataoke.com/api/tb-service/twd-to-twd"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def goods_first_order_gift_money(
        self, args: GoodsFirstOrderGiftMoneyArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=29
        """
        url = "https://openapi.dataoke.com/api/goods/first-order-gift-money"
        version = "v1.1.0"
        return self._do_request(url, version, args.dict())

    def tb_service_creat_taokouling(
        self, args: TbServiceCreatTaokoulingArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=28
        """
        url = "https://openapi.dataoke.com/api/tb-service/creat-taokouling"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def tb_service_get_order_details(
        self, args: TbServiceGetOrderDetailsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=27
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-order-details"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def tb_service_parse_taokouling(
        self, args: TbServiceParseTaokoulingArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=26
        """
        url = "https://openapi.dataoke.com/api/tb-service/parse-taokouling"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def tb_service_get_privilege_link(
        self, args: TbServiceGetPrivilegeLinkArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=7
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-privilege-link"
        version = "v1.3.1"
        return self._do_request(url, version, args.dict())

    def goods_nine_op_goods_list(
        self, args: GoodsNineOpGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=15
        """
        url = "https://openapi.dataoke.com/api/goods/nine/op-goods-list"
        version = "v2.0.0"
        return self._do_request(url, version, args.dict())

    def category_ddq_goods_list(self, args: CategoryDdqGoodsListArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=23
        """
        url = "https://openapi.dataoke.com/api/category/ddq-goods-list"
        version = "v1.2.1"
        return self._do_request(url, version, args.dict())

    def goods_get_ranking_list(self, args: GoodsGetRankingListArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=6
        """
        url = "https://openapi.dataoke.com/api/goods/get-ranking-list"
        version = "v1.3.0"
        return self._do_request(url, version, args.dict())

    def goods_friends_circle_list(
        self, args: GoodsFriendsCircleListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=25
        """
        url = "https://openapi.dataoke.com/api/goods/friends-circle-list"
        version = "v1.3.0"
        return self._do_request(url, version, args.dict())

    def goods_topic_catalogue(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=21
        """
        url = "https://openapi.dataoke.com/api/goods/topic/catalogue"
        version = "v1.1.0"
        return self._do_request(url, version, dict())

    def goods_topic_goods_list(self, args: GoodsTopicGoodsListArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=22
        """
        url = "https://openapi.dataoke.com/api/goods/topic/goods-list"
        version = "v1.2.2"
        return self._do_request(url, version, args.dict())

    def category_get_tb_topic_list(
        self, args: CategoryGetTbTopicListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=24
        """
        url = "https://openapi.dataoke.com/api/category/get-tb-topic-list"
        version = "v1.2.0"
        return self._do_request(url, version, args.dict())

    def tb_service_get_brand_list(
        self, args: TbServiceGetBrandListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=17
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-brand-list"
        version = "v1.1.2"
        return self._do_request(url, version, args.dict())

    def goods_search_suggestion(
        self, args: GoodsSearchSuggestionArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=18
        """
        url = "https://openapi.dataoke.com/api/goods/search-suggestion"
        version = "v1.0.2"
        return self._do_request(url, version, args.dict())

    def goods_list_super_goods(self, args: GoodsListSuperGoodsArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=14
        """
        url = "https://openapi.dataoke.com/api/goods/list-super-goods"
        version = "v1.3.0"
        return self._do_request(url, version, args.dict())

    def goods_list_similer_goods_by_open(
        self, args: GoodsListSimilerGoodsByOpenArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=16
        """
        url = "https://openapi.dataoke.com/api/goods/list-similer-goods-by-open"
        version = "v1.2.2"
        return self._do_request(url, version, args.dict())

    def goods_get_goods_list(self, args: GoodsGetGoodsListArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=5
        """
        url = "https://openapi.dataoke.com/api/goods/get-goods-list"
        version = "v1.2.4"
        return self._do_request(url, version, args.dict())

    def goods_get_goods_details(self, args: GoodsGetGoodsDetailsArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=8
        """
        url = "https://openapi.dataoke.com/api/goods/get-goods-details"
        version = "v1.2.3"
        return self._do_request(url, version, args.dict())

    def goods_get_dtk_search_goods(
        self, args: GoodsGetDtkSearchGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=9
        """
        url = "https://openapi.dataoke.com/api/goods/get-dtk-search-goods"
        version = "v2.1.2"
        return self._do_request(url, version, args.dict())

    def goods_pull_goods_by_time(
        self, args: GoodsPullGoodsByTimeArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=12
        """
        url = "https://openapi.dataoke.com/api/goods/pull-goods-by-time"
        version = "v1.2.3"
        return self._do_request(url, version, args.dict())

    def category_get_top100(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=4
        """
        url = "https://openapi.dataoke.com/api/category/get-top100"
        version = "v1.0.1"
        return self._do_request(url, version, dict())

    def goods_get_stale_goods_by_time(
        self, args: GoodsGetStaleGoodsByTimeArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=11
        """
        url = "https://openapi.dataoke.com/api/goods/get-stale-goods-by-time"
        version = "v1.0.1"
        return self._do_request(url, version, args.dict())

    def goods_get_newest_goods(self, args: GoodsGetNewestGoodsArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=3
        """
        url = "https://openapi.dataoke.com/api/goods/get-newest-goods"
        version = "v1.2.0"
        return self._do_request(url, version, args.dict())

    def category_get_super_category(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=10
        """
        url = "https://openapi.dataoke.com/api/category/get-super-category"
        version = "v1.1.0"
        return self._do_request(url, version, dict())

    def tb_service_get_tb_service(
        self, args: TbServiceGetTbServiceArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=13
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-tb-service"
        version = "v2.1.0"
        return self._do_request(url, version, args.dict())

    def goods_get_collection_list(
        self, args: GoodsGetCollectionListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=1
        """
        url = "https://openapi.dataoke.com/api/goods/get-collection-list"
        version = "v1.0.1"
        return self._do_request(url, version, args.dict())

    def goods_get_owner_goods(self, args: GoodsGetOwnerGoodsArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=2
        """
        url = "https://openapi.dataoke.com/api/goods/get-owner-goods"
        version = "v1.0.1"
        return self._do_request(url, version, args.dict())

    def goods_activity_goods_list(
        self, args: GoodsActivityGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=20
        """
        url = "https://openapi.dataoke.com/api/goods/activity/goods-list"
        version = "v1.2.2"
        return self._do_request(url, version, args.dict())

    def goods_activity_catalogue(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=19
        """
        url = "https://openapi.dataoke.com/api/goods/activity/catalogue"
        version = "v1.1.0"
        return self._do_request(url, version, dict())

    def goods_jd_one_dollar_purchase(
        self, args: GoodsJdOneDollarPurchaseArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=40
        """
        url = "https://openapi.dataoke.com/api/goods/jd-one-dollar-purchase"
        version = "v1.0.1"
        return self._do_request(url, version, args.dict())

    def dels_jd_order_outer_get_order_list(
        self, args: DelsJdOrderOuterGetOrderListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=50
        """
        url = "https://openapi.dataoke.com/api/dels/jd/order/outer/get-order-list"
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())

    def dels_jd_kit_outer_promotion_union_convert(
        self, args: DelsJdKitOuterPromotionUnionConvertArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=49
        """
        url = (
            "https://openapi.dataoke.com/api/dels/jd/kit/outer/promotion-union-convert"
        )
        version = "v1.0.0"
        return self._do_request(url, version, args.dict())


class DtkAsync(DtkBase):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._session = ClientSession()

    async def _do_request(
        self, url: str, version: str, merge_args: dict
    ) -> Optional[dict]:
        data = self.merge_args(merge_args, version)
        query = parse.urlencode(data)
        async with self._session.get(f"{url}?{query}") as resp:
            if 200 <= resp.status < 300:
                text = await resp.text()
                return json.loads(text)
            return None

    async def dels_jd_kit_promotion_union_convert(
        self, args: DelsJdKitPromotionUnionConvertArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=52
        """
        url = "https://openapi.dataoke.com/api/dels/jd/kit/promotion-union-convert"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def dels_jd_order_get_official_order_list(
        self, args: DelsJdOrderGetOfficialOrderListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=51
        """
        url = "https://openapi.dataoke.com/api/dels/jd/order/get-official-order-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_get_history_low_price_list(
        self, args: GoodsGetHistoryLowPriceListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=48
        """
        url = "https://openapi.dataoke.com/api/goods/get-history-low-price-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def delanys_media_video_get_goods_list(
        self, args: DelanysMediaVideoGetGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=46
        """
        url = "https://openapi.dataoke.com/api/delanys/media/video/get-goods-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def delanys_media_video_get_category_list(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=47
        """
        url = "https://openapi.dataoke.com/api/delanys/media/video/get-category-list"
        version = "v1.0.0"
        return await self._do_request(url, version, dict())

    async def delanys_brand_get_goods_list(
        self, args: DelanysBrandGetGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=45
        """
        url = "https://openapi.dataoke.com/api/delanys/brand/get-goods-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def delanys_brand_get_column_list(
        self, args: DelanysBrandGetColumnListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=44
        """
        url = "https://openapi.dataoke.com/api/delanys/brand/get-column-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def comment_get_comment_list(
        self, args: CommentGetCommentListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=43
        """
        url = "https://openapi.dataoke.com/api/comment/get-comment-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def dels_shop_convert(self, args: DelsShopConvertArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=42
        """
        url = "https://openapi.dataoke.com/api/dels/shop/convert"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def subdivision_get_rank_list(
        self, args: SubdivisionGetRankListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=41
        """
        url = "https://openapi.dataoke.com/api/subdivision/get-rank-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_super_discount_goods(
        self, args: GoodsSuperDiscountGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=39
        """
        url = "https://openapi.dataoke.com/api/goods/super-discount-goods"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_get_half_price_day(
        self, args: GoodsGetHalfPriceDayArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=38
        """
        url = "https://openapi.dataoke.com/api/goods/get-half-price-day"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def dels_merge_red_envelopes(
        self, args: DelsMergeRedEnvelopesArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=37
        """
        url = "https://openapi.dataoke.com/api/dels/merge-red-envelopes"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_price_trend(self, args: GoodsPriceTrendArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=36
        """
        url = "https://openapi.dataoke.com/api/goods/price-trend"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_liveMaterial_goods_list(
        self, args: GoodsLivematerialGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=35
        """
        url = "https://openapi.dataoke.com/api/goods/liveMaterial-goods-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_explosive_goods_list(
        self, args: GoodsExplosiveGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=34
        """
        url = "https://openapi.dataoke.com/api/goods/explosive-goods-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_parse_content(
        self, args: TbServiceParseContentArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=33
        """
        url = "https://openapi.dataoke.com/api/tb-service/parse-content"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_exclusive_goods_list(
        self, args: GoodsExclusiveGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=32
        """
        url = "https://openapi.dataoke.com/api/goods/exclusive-goods-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_activity_link(
        self, args: TbServiceActivityLinkArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=31
        """
        url = "https://openapi.dataoke.com/api/tb-service/activity-link"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_twd_to_twd(
        self, args: TbServiceTwdToTwdArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=30
        """
        url = "https://openapi.dataoke.com/api/tb-service/twd-to-twd"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def goods_first_order_gift_money(
        self, args: GoodsFirstOrderGiftMoneyArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=29
        """
        url = "https://openapi.dataoke.com/api/goods/first-order-gift-money"
        version = "v1.1.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_creat_taokouling(
        self, args: TbServiceCreatTaokoulingArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=28
        """
        url = "https://openapi.dataoke.com/api/tb-service/creat-taokouling"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_get_order_details(
        self, args: TbServiceGetOrderDetailsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=27
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-order-details"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_parse_taokouling(
        self, args: TbServiceParseTaokoulingArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=26
        """
        url = "https://openapi.dataoke.com/api/tb-service/parse-taokouling"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_get_privilege_link(
        self, args: TbServiceGetPrivilegeLinkArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=7
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-privilege-link"
        version = "v1.3.1"
        return await self._do_request(url, version, args.dict())

    async def goods_nine_op_goods_list(
        self, args: GoodsNineOpGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=15
        """
        url = "https://openapi.dataoke.com/api/goods/nine/op-goods-list"
        version = "v2.0.0"
        return await self._do_request(url, version, args.dict())

    async def category_ddq_goods_list(
        self, args: CategoryDdqGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=23
        """
        url = "https://openapi.dataoke.com/api/category/ddq-goods-list"
        version = "v1.2.1"
        return await self._do_request(url, version, args.dict())

    async def goods_get_ranking_list(
        self, args: GoodsGetRankingListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=6
        """
        url = "https://openapi.dataoke.com/api/goods/get-ranking-list"
        version = "v1.3.0"
        return await self._do_request(url, version, args.dict())

    async def goods_friends_circle_list(
        self, args: GoodsFriendsCircleListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=25
        """
        url = "https://openapi.dataoke.com/api/goods/friends-circle-list"
        version = "v1.3.0"
        return await self._do_request(url, version, args.dict())

    async def goods_topic_catalogue(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=21
        """
        url = "https://openapi.dataoke.com/api/goods/topic/catalogue"
        version = "v1.1.0"
        return await self._do_request(url, version, dict())

    async def goods_topic_goods_list(
        self, args: GoodsTopicGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=22
        """
        url = "https://openapi.dataoke.com/api/goods/topic/goods-list"
        version = "v1.2.2"
        return await self._do_request(url, version, args.dict())

    async def category_get_tb_topic_list(
        self, args: CategoryGetTbTopicListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=24
        """
        url = "https://openapi.dataoke.com/api/category/get-tb-topic-list"
        version = "v1.2.0"
        return await self._do_request(url, version, args.dict())

    async def tb_service_get_brand_list(
        self, args: TbServiceGetBrandListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=17
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-brand-list"
        version = "v1.1.2"
        return await self._do_request(url, version, args.dict())

    async def goods_search_suggestion(
        self, args: GoodsSearchSuggestionArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=18
        """
        url = "https://openapi.dataoke.com/api/goods/search-suggestion"
        version = "v1.0.2"
        return await self._do_request(url, version, args.dict())

    async def goods_list_super_goods(
        self, args: GoodsListSuperGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=14
        """
        url = "https://openapi.dataoke.com/api/goods/list-super-goods"
        version = "v1.3.0"
        return await self._do_request(url, version, args.dict())

    async def goods_list_similer_goods_by_open(
        self, args: GoodsListSimilerGoodsByOpenArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=16
        """
        url = "https://openapi.dataoke.com/api/goods/list-similer-goods-by-open"
        version = "v1.2.2"
        return await self._do_request(url, version, args.dict())

    async def goods_get_goods_list(self, args: GoodsGetGoodsListArgs) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=5
        """
        url = "https://openapi.dataoke.com/api/goods/get-goods-list"
        version = "v1.2.4"
        return await self._do_request(url, version, args.dict())

    async def goods_get_goods_details(
        self, args: GoodsGetGoodsDetailsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=8
        """
        url = "https://openapi.dataoke.com/api/goods/get-goods-details"
        version = "v1.2.3"
        return await self._do_request(url, version, args.dict())

    async def goods_get_dtk_search_goods(
        self, args: GoodsGetDtkSearchGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=9
        """
        url = "https://openapi.dataoke.com/api/goods/get-dtk-search-goods"
        version = "v2.1.2"
        return await self._do_request(url, version, args.dict())

    async def goods_pull_goods_by_time(
        self, args: GoodsPullGoodsByTimeArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=12
        """
        url = "https://openapi.dataoke.com/api/goods/pull-goods-by-time"
        version = "v1.2.3"
        return await self._do_request(url, version, args.dict())

    async def category_get_top100(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=4
        """
        url = "https://openapi.dataoke.com/api/category/get-top100"
        version = "v1.0.1"
        return await self._do_request(url, version, dict())

    async def goods_get_stale_goods_by_time(
        self, args: GoodsGetStaleGoodsByTimeArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=11
        """
        url = "https://openapi.dataoke.com/api/goods/get-stale-goods-by-time"
        version = "v1.0.1"
        return await self._do_request(url, version, args.dict())

    async def goods_get_newest_goods(
        self, args: GoodsGetNewestGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=3
        """
        url = "https://openapi.dataoke.com/api/goods/get-newest-goods"
        version = "v1.2.0"
        return await self._do_request(url, version, args.dict())

    async def category_get_super_category(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=10
        """
        url = "https://openapi.dataoke.com/api/category/get-super-category"
        version = "v1.1.0"
        return await self._do_request(url, version, dict())

    async def tb_service_get_tb_service(
        self, args: TbServiceGetTbServiceArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=13
        """
        url = "https://openapi.dataoke.com/api/tb-service/get-tb-service"
        version = "v2.1.0"
        return await self._do_request(url, version, args.dict())

    async def goods_get_collection_list(
        self, args: GoodsGetCollectionListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=1
        """
        url = "https://openapi.dataoke.com/api/goods/get-collection-list"
        version = "v1.0.1"
        return await self._do_request(url, version, args.dict())

    async def goods_get_owner_goods(
        self, args: GoodsGetOwnerGoodsArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=2
        """
        url = "https://openapi.dataoke.com/api/goods/get-owner-goods"
        version = "v1.0.1"
        return await self._do_request(url, version, args.dict())

    async def goods_activity_goods_list(
        self, args: GoodsActivityGoodsListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=20
        """
        url = "https://openapi.dataoke.com/api/goods/activity/goods-list"
        version = "v1.2.2"
        return await self._do_request(url, version, args.dict())

    async def goods_activity_catalogue(self) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=19
        """
        url = "https://openapi.dataoke.com/api/goods/activity/catalogue"
        version = "v1.1.0"
        return await self._do_request(url, version, dict())

    async def goods_jd_one_dollar_purchase(
        self, args: GoodsJdOneDollarPurchaseArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=40
        """
        url = "https://openapi.dataoke.com/api/goods/jd-one-dollar-purchase"
        version = "v1.0.1"
        return await self._do_request(url, version, args.dict())

    async def dels_jd_order_outer_get_order_list(
        self, args: DelsJdOrderOuterGetOrderListArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=50
        """
        url = "https://openapi.dataoke.com/api/dels/jd/order/outer/get-order-list"
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())

    async def dels_jd_kit_outer_promotion_union_convert(
        self, args: DelsJdKitOuterPromotionUnionConvertArgs
    ) -> Optional[dict]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=49
        """
        url = (
            "https://openapi.dataoke.com/api/dels/jd/kit/outer/promotion-union-convert"
        )
        version = "v1.0.0"
        return await self._do_request(url, version, args.dict())



from typing import Optional, Dict, List

from pydantic import BaseModel


class ItemDetailResp(BaseModel):
    """
    商品详情返回信息
    """

    cat_leaf_name: str
    cat_name: str
    item_url: str
    ju_online_end_time: str
    ju_online_start_time: str
    ju_pre_show_end_time: str
    ju_pre_show_start_time: str
    material_lib_type: str
    nick: str
    num_iid: str
    pict_url: str
    presale_deposit: str
    presale_end_time: str
    presale_start_time: str
    presale_tail_end_time: str
    presale_tail_start_time: str
    provcity: str
    reserve_price: str
    seller_id: str
    small_images: Dict[str, Optional[List[str]]]
    title: str
    tmall_play_activity_end_time: int
    tmall_play_activity_start_time: int
    user_type: int
    volume: int
    zk_final_price: str
    kuadian_promotion_info: Optional[str] = None

    @staticmethod
    def from_ztk_resp(j: dict) -> Optional["ItemDetailResp"]:
        if "tbk_item_info_get_response" not in j:
            return None
        j = j["tbk_item_info_get_response"]

        if "results" not in j:
            return None
        j = j["results"]

        if "n_tbk_item" not in j:
            return None
        j = j["n_tbk_item"]

        if isinstance(j, list) and len(j) >= 1:
            return ItemDetailResp(**j[0])
        else:
            return None



from .base_args import BaseArgs


class KeywordArgs(BaseArgs):
    """
    关键词词典

    :doc https://www.zhetaoke.com/user/extend/extend_lingquan_guanjianci.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/api_guanjianci.ashx"

    page: int = 1
    page_size: int = 10
    type: int = 1



from typing import Union, Optional

from aiohttp.client import ClientSession

from .dt import AppleConfig
from .dt import AppleSignInSuccessRet, AppleSignInFailureRet
from .shared import Shared

__all__ = ["AppleSignInAsyncApi"]


class AppleSignInAsyncApi(Shared):
    """
    苹果登陆异步处理接口

    Apple SignIn async process interface
    """

    def __init__(self, config: AppleConfig):
        super().__init__(config)
        self._session = ClientSession()

    async def try_auth(
        self, code: str
    ) -> Optional[Union[AppleSignInSuccessRet, AppleSignInFailureRet]]:
        """
        尝试进行 code 的认证
        :param code: 授权code
        :return:
        """
        headers, data = self._make_up_data(code)

        resp = await self._session.post(
            self.ACCESS_TOKEN_URL, data=data, headers=headers
        )
        if not (200 <= resp.status < 300):
            # network or apple server is down
            return None

        ret = await resp.json()
        assert isinstance(ret, dict)
        if "error" in ret:
            return AppleSignInFailureRet(**ret)
        else:
            return AppleSignInSuccessRet(**ret)



import hashlib
from datetime import datetime
from urllib import parse

from .exceptions import TopErrorRespException

__all__ = ["BaseApi"]


class BaseApi(object):
    """
    阿里百川 Python SDK
    """

    base_url = "https://eco.taobao.com/router/rest"

    def __init__(self, app_key: str, app_secret: str):
        """
        淘宝开放平台 API

        :param app_key:
        :param app_secret:
        """
        self._app_key = app_key
        self._app_secret = app_secret

    @staticmethod
    def _get_real_data(method: str, d: dict) -> dict:
        parts = method.split(".")[1:]
        key = "_".join(parts) + "_response"
        if key in d:
            return d[key]
        raise TopErrorRespException(d)

    def _to_url(self, d: dict) -> str:
        """
        转换成需要请求的 URL

        :param d: 请求的参数
        :return:
        """
        data = self._to_data(d)
        query = parse.urlencode(data)
        return f"{self.base_url}?{query}"

    def _to_data(self, d: dict) -> dict:
        d["app_key"] = self._app_key
        d["format"] = "json"
        d["v"] = "2.0"
        d["sign_method"] = "md5"
        t = datetime.now()
        d[
            "timestamp"
        ] = f"{t.year:04}-{t.month:02}-{t.day:02} {t.hour:02}:{t.minute:02}:{t.second:02}"

        # remove none value
        n = {k: v for k, v in d.items() if v is not None}

        sign = self._create_sign(n, self._app_secret)
        n["sign"] = sign
        return n

    @staticmethod
    def _create_sign(d: dict, secret: str):
        """
        copy from https://open.taobao.com/doc.htm?docId=131&docType=1

        :param d:
        :param secret:
        :return:
        """
        k = d.keys()
        k = sorted(k)

        sign = secret
        for key in k:
            value = d[key]
            if key != "" and value != "":
                sign = f"{sign}{key}{value}"
        sign = f"{sign}{secret}"

        d = hashlib.md5(sign.encode())

        return d.hexdigest().upper()



from typing import Iterable


def gen_n(n: int) -> Iterable[int]:
    for i in range(n):
        yield from range(i)


def test_coroutine_simple():
    """
    测试 coroutine 函数
    :return:
    """
    for i in gen_n(4):
        print(i)



from typing import List, Optional

from pydantic import BaseModel, Field


class HTTPValidationError(object):
    # Detail
    detail: Optional[List["ValidationError"]] = None


class PushForm(BaseModel):
    # iOS 设备的 token
    # HEX 编码的 iOS 设备的token
    token: str
    # 内容
    # 推送给客户端的内容
    content: str
    # 角标数量
    # 客户端显示的角标的数量
    badge: Optional[int] = Field(0)
    # 推送分类
    # 客户端推送的分类
    category: Optional[str] = Field(None)
    # sandbox 环境
    # 是否使用 sandbox 环境
    sandbox: Optional[bool] = Field(False)


class ValidationError(object):
    # Location
    loc: List[str]
    # Message
    msg: str
    # Error Type
    type: str



import base64
import hmac
import secrets
import time
from datetime import datetime
from urllib import parse

__all__ = ["AliSmsBase"]


class AliSmsBase(object):
    """
    阿里短信基础类
    """

    endpoint = "https://dysmsapi.aliyuncs.com/"

    def __init__(self, access_key: str, access_secret: str):
        self._app_key = access_key
        self._app_secret = access_secret

    def merge_args(self, args: dict, method: str = "POST") -> dict:
        d = {
            key: value
            for key, value in args.items()
            if value is not None and value != ""
        }

        # 添加公共请求参数
        # doc: https://help.aliyun.com/document_detail/101341.html
        t = datetime.utcfromtimestamp(int(time.time()))

        d["Format"] = "JSON"
        d["AccessKeyId"] = self._app_key
        d["SignatureMethod"] = "HMAC-SHA1"
        d["SignatureNonce"] = secrets.token_urlsafe(16)
        d["SignatureVersion"] = "1.0"
        d["Timestamp"] = f"{t.isoformat()}Z"
        d["Version"] = "2017-05-25"

        d["Signature"] = self._compute_signature(d, method, self._app_secret)

        return d

    @staticmethod
    def _compute_signature(d: dict, method: str, access_secret: str) -> str:
        """
        计算签名
            https://help.aliyun.com/document_detail/101343.html

        :param d:
        :param method: http method
        :param access_secret:
        :return:
        """

        # 2. 根据参数Key排序（顺序）
        # 3. 构造待签名的请求串
        sorted_params = sorted(d.items())
        t1 = parse.urlencode(sorted_params)
        t2 = parse.quote_plus(t1)

        data = f"{method}&%2F&{t2}"

        return AliSmsBase.compute_str_signature(data, access_secret + "&")

    @staticmethod
    def compute_str_signature(s: str, access_secret: str) -> str:
        signature = hmac.digest(access_secret.encode(), s.encode(), "sha1")
        return base64.b64encode(signature).decode()



from .gen import *  # noqa

__all__ = ["DtkAsyncApi"]


class DtkAsyncApi(object):
    """"""

    def __init__(self, app_key: str, app_secret: str):
        self._inner = DtkAsync(app_key=app_key, app_secret=app_secret)

    @staticmethod
    def _generic_get_data(d: Optional[dict]) -> Optional[dict]:
        if isinstance(d, dict) and d["code"] == 0:
            return d["data"]
        return None

    async def goods_price_trend(
        self, args: GoodsPriceTrendArgs
    ) -> Optional[GoodsPriceTrendResp]:
        """
        doc: https://www.dataoke.com/pmc/api-d.html?id=36
        """
        ret = await self._inner.goods_price_trend(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return GoodsPriceTrendResp(**data)

    async def goods_liveMaterial_goods_list(
        self, args: GoodsLivematerialGoodsListArgs
    ) -> Optional[dict]:
        return await self._inner.goods_liveMaterial_goods_list(args)

    async def goods_explosive_goods_list(
        self, args: GoodsExplosiveGoodsListArgs
    ) -> Optional[List[GoodsExplosiveGoodsListResp]]:
        ret = await self._inner.goods_explosive_goods_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsExplosiveGoodsListResp(**x), data["list"]))

    async def tb_service_parse_content(
        self, args: TbServiceParseContentArgs
    ) -> Optional[dict]:
        return await self._inner.tb_service_parse_content(args)

    async def goods_exclusive_goods_list(
        self, args: GoodsExclusiveGoodsListArgs
    ) -> Optional[List[GoodsExclusiveGoodsListResp]]:
        ret = await self._inner.goods_exclusive_goods_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsExclusiveGoodsListResp(**x), data["list"]))

    async def tb_service_activity_link(
        self, args: TbServiceActivityLinkArgs
    ) -> Optional[TbServiceGetPrivilegeLinkResp]:
        ret = await self._inner.tb_service_activity_link(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return TbServiceGetPrivilegeLinkResp(**data)

    async def tb_service_twd_to_twd(
        self, args: TbServiceTwdToTwdArgs
    ) -> Optional[dict]:
        return await self._inner.tb_service_twd_to_twd(args)

    async def goods_first_order_gift_money(
        self, args: GoodsFirstOrderGiftMoneyArgs
    ) -> Optional[dict]:
        return await self._inner.goods_first_order_gift_money(args)

    async def tb_service_creat_taokouling(
        self, args: TbServiceCreatTaokoulingArgs
    ) -> Optional[TbServiceCreatTaokoulingResp]:
        ret = await self._inner.tb_service_creat_taokouling(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return TbServiceCreatTaokoulingResp(**data)

    async def tb_service_get_order_details(
        self, args: TbServiceGetOrderDetailsArgs
    ) -> Optional[dict]:
        return await self._inner.tb_service_get_order_details(args)

    async def tb_service_parse_taokouling(
        self, args: TbServiceParseTaokoulingArgs
    ) -> Optional[TbServiceParseTaokoulingResp]:
        ret = await self._inner.tb_service_parse_taokouling(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return TbServiceParseTaokoulingResp(**data)

    async def tb_service_get_privilege_link(
        self, args: TbServiceGetPrivilegeLinkArgs
    ) -> Optional[TbServiceGetPrivilegeLinkResp]:
        ret = await self._inner.tb_service_get_privilege_link(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return TbServiceGetPrivilegeLinkResp(**data)

    async def goods_nine_op_goods_list(
        self, args: GoodsNineOpGoodsListArgs
    ) -> Optional[GoodsNineOpGoodsListResp]:
        ret = await self._inner.goods_nine_op_goods_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return GoodsNineOpGoodsListResp(**data)

    async def category_ddq_goods_list(
        self, args: CategoryDdqGoodsListArgs
    ) -> Optional[CategoryDdqGoodsListResp]:
        ret = await self._inner.category_ddq_goods_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return CategoryDdqGoodsListResp(**data)

    async def goods_get_ranking_list(
        self, args: GoodsGetRankingListArgs
    ) -> Optional[List[GoodsGetRankingListResp]]:
        ret = await self._inner.goods_get_ranking_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsGetRankingListResp(**x), data))

    async def goods_friends_circle_list(
        self, args: GoodsFriendsCircleListArgs
    ) -> Optional[dict]:
        return await self._inner.goods_friends_circle_list(args)

    async def goods_topic_catalogue(self) -> Optional[List[GoodsTopicCatalogueResp]]:
        ret = await self._inner.goods_topic_catalogue()
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsTopicCatalogueResp(**x), data))

    async def goods_topic_goods_list(
        self, args: GoodsTopicGoodsListArgs
    ) -> Optional[dict]:
        return await self._inner.goods_topic_goods_list(args)

    async def category_get_tb_topic_list(
        self, args: CategoryGetTbTopicListArgs
    ) -> Optional[dict]:
        return await self._inner.category_get_tb_topic_list(args)

    async def tb_service_get_brand_list(
        self, args: TbServiceGetBrandListArgs
    ) -> Optional[List[TbServiceGetBrandListResp]]:
        ret = await self._inner.tb_service_get_brand_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: TbServiceGetBrandListResp(**x), data))

    async def goods_search_suggestion(
        self, args: GoodsSearchSuggestionArgs
    ) -> Optional[List[GoodsSearchSuggestionResp]]:
        ret = await self._inner.goods_search_suggestion(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsSearchSuggestionResp(**x), data))

    async def goods_list_super_goods(
        self, args: GoodsListSuperGoodsArgs
    ) -> Optional[List[GoodsListSuperGoodsResp]]:
        ret = await self._inner.goods_list_super_goods(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsListSuperGoodsResp(**x), data["list"]))

    async def goods_list_similer_goods_by_open(
        self, args: GoodsListSimilerGoodsByOpenArgs
    ) -> Optional[List[GoodsListSimilerGoodsByOpenResp]]:
        ret = await self._inner.goods_list_similer_goods_by_open(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsListSimilerGoodsByOpenResp(**x), data))

    async def goods_get_goods_list(
        self, args: GoodsGetGoodsListArgs
    ) -> Optional[List[GoodsGetGoodsListResp]]:
        ret = await self._inner.goods_get_goods_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsGetGoodsListResp(**x), data["list"]))

    async def goods_get_goods_details(
        self, args: GoodsGetGoodsDetailsArgs
    ) -> Optional[GoodsGetGoodsDetailsResp]:
        ret = await self._inner.goods_get_goods_details(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return GoodsGetGoodsDetailsResp(**data)

    async def goods_get_dtk_search_goods(
        self, args: GoodsGetDtkSearchGoodsArgs
    ) -> Optional[GoodsGetDtkSearchGoodsResp]:
        ret = await self._inner.goods_get_dtk_search_goods(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return GoodsGetDtkSearchGoodsResp(**data)

    async def goods_pull_goods_by_time(
        self, args: GoodsPullGoodsByTimeArgs
    ) -> Optional[dict]:
        return await self._inner.goods_pull_goods_by_time(args)

    async def category_get_top100(self) -> Optional[CategoryGetTop100Resp]:
        ret = await self._inner.category_get_top100()
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return CategoryGetTop100Resp(**data)

    async def goods_get_stale_goods_by_time(
        self, args: GoodsGetStaleGoodsByTimeArgs
    ) -> Optional[dict]:
        return await self._inner.goods_get_stale_goods_by_time(args)

    async def goods_get_newest_goods(
        self, args: GoodsGetNewestGoodsArgs
    ) -> Optional[dict]:
        return await self._inner.goods_get_newest_goods(args)

    async def category_get_super_category(
        self,
    ) -> Optional[List[CategoryGetSuperCategoryResp]]:
        ret = await self._inner.category_get_super_category()
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: CategoryGetSuperCategoryResp(**x), data))

    async def tb_service_get_tb_service(
        self, args: TbServiceGetTbServiceArgs
    ) -> Optional[List[TbServiceGetTbServiceResp]]:
        ret = await self._inner.tb_service_get_tb_service(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: TbServiceGetTbServiceResp(**x), data))

    async def goods_get_collection_list(
        self, args: GoodsGetCollectionListArgs
    ) -> Optional[dict]:
        return await self._inner.goods_get_collection_list(args)

    async def goods_get_owner_goods(
        self, args: GoodsGetOwnerGoodsArgs
    ) -> Optional[dict]:
        return await self._inner.goods_get_owner_goods(args)

    async def goods_activity_goods_list(
        self, args: GoodsActivityGoodsListArgs
    ) -> Optional[dict]:
        return await self._inner.goods_activity_goods_list(args)

    async def goods_activity_catalogue(
        self,
    ) -> Optional[List[GoodsActivityCatalogueResp]]:
        ret = await self._inner.goods_activity_catalogue()
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: GoodsActivityCatalogueResp(**x), data))

    async def delanys_brand_get_goods_list(
        self, args: DelanysBrandGetGoodsListArgs
    ) -> Optional[List[DelanysBrandGetGoodsListResp]]:

        ret = await self._inner.delanys_brand_get_goods_list(args)
        data = self._generic_get_data(ret)
        if data is None:
            return None
        return list(map(lambda x: DelanysBrandGetGoodsListResp(**x), data["list"]))



from typing import Optional

from .base_args import BaseArgs


class GuessYouLikeArgs(BaseArgs):
    """
    折淘客 猜你喜欢接口参数

    :doc https://www.zhetaoke.com/user/open/open_item_guess_like.aspx
    """

    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10001/api/open_item_guess_like.ashx"

    page: int = 1
    """
    分页获取数据,第几页
    """

    page_size: int = 20
    """
    每页数据条数（默认每页20条），可自定义1-50之间
    """

    sort: str = "new"
    """
    商品排序方式，
    new：按照综合排序，
    total_sale_num_asc：按照总销量从小到大排序，total_sale_num_desc：按照总销量从大到小排序，
    sale_num_asc：按照月销量从小到大排序，sale_num_desc：按照月销量从大到小排序，
    commission_rate_asc：按照佣金比例从小到大排序，commission_rate_desc：按照佣金比例从大到小排序，
    price_asc：按照价格从小到大排序，price_desc：按照价格从大到小排序，
    coupon_info_money_asc：按照优惠券金额从小到大排序，coupon_info_money_desc：按照优惠券金额从大到小排序，
    shop_level_asc：按照店铺等级从低到高排序，shop_level_desc：按照店铺等级从高到低排序，
    tkfee_asc：按照返佣金额从低到高排序，tkfee_desc：按照返佣金额从高到低排序，
    code：按照code值从大到小排序，date_time：按照更新时间排序，random：按照随机排序
    """

    device_value: Optional[str] = None
    """
    设备号加密后的值（MD5加密需32位小写）
    """

    device_encrypt: Optional[str] = None
    """
    设备号加密类型：MD5
    """

    device_type: Optional[str] = None
    """
    设备号类型：IMEI，或者IDFA，或者UTDID（UTDID不支持MD5加密）
    """

    item_id: Optional[str] = None
    """
    商品ID：如果该值非空，那么device_value、device_encrypt和device_type无效，反之，如果这三个值非空，那么商品ID无效
    """



from typing import Optional

from .base_args import BaseArgs


class GaoYongArgs(BaseArgs):
    """
    高佣转链API (商品ID)

    :doc: https://www.zhetaoke.com/user/open/open_gaoyongzhuanlian.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/open_gaoyongzhuanlian.ashx"

    # 淘客PID，mm_xxx_xxx_xxx,三段格式，必须与授权的账户相同，否则出错
    pid: str

    # 商品ID,商品ID或me必须填一个
    num_iid: Optional[str] = None

    # 团长与下游渠道合作的特殊标识，用于统计渠道推广效果
    xid: Optional[str] = None

    # 渠道关系ID，仅适用于渠道推广场景。
    relation_id: Optional[str] = None

    # 会员运营ID
    special_id: Optional[str] = None

    # 淘宝客外部用户标记，如自身系统账户ID；微信ID等
    external_id: Optional[str] = None

    # signurl=5，返回结果整合高佣转链API、解析商品编号API、全网商品详情API、淘口令创建API，已经自动判断和拼接使用全网G券还是全网S券。
    # signurl=4，返回结果整合高佣转链API、解析商品编号API、商品简版详情API、淘口令创建API，已经自动判断和拼接使用全网G券还是全网S券。
    # signurl=3，返回结果整合高佣转链API、解析商品编号API，已经自动判断和拼接使用全网G券还是全网S券。
    # signurl=0或1或2，返回官方高佣转链接口结果，需要自行判断和拼接使用全网G券或者全网S券。
    # signurl=0，表示直接返回最终结果。
    # signurl=1或2，表示返回淘宝联盟请求地址，大家拿到地址后再用自己的服务器二次请求即可获得最终结果，值为1返回http链接，值为2返回https安全链接。
    signurl: int = 5

    # 对应的淘客账号授权ID点击查看
    sid: str = ""



from requests import Session, Response

from .dt import PushForm

__all__ = ["APNsSync"]


class APNsSync(object):
    def __init__(self, base_url: str):
        self._base_url = base_url
        self._session = Session()

    def push(self, form: PushForm) -> bool:
        """
        推送一条信息给 iOS 设备

        推送消息给 指定的 iOS 设备
        """
        url = self._get_url_by_path("/push")
        resp = self._do_request(method="POST", url=url, data=form.dict(by_alias=True))

        if resp.ok:
            return True
        else:
            return False

    def _get_url_by_path(self, path: str) -> str:
        return f"{self._base_url}{path}"

    def _do_request(self, method: str, url: str, data: dict) -> Response:
        return self._session.request(method=method, url=url, json=data)



from typing import Union, Optional

from requests import Session

from .dt import AppleConfig, AppleSignInSuccessRet, AppleSignInFailureRet
from .shared import Shared

__all__ = ["AppleSignInApi"]


class AppleSignInApi(Shared):
    """
    苹果登陆同步处理接口
    """

    def __init__(self, config: AppleConfig):
        super().__init__(config)
        self._session = Session()

    def try_auth(
        self, code: str
    ) -> Optional[Union[AppleSignInSuccessRet, AppleSignInFailureRet]]:
        """
        尝试进行 code 的认证
        :param code: 授权code
        :return:
        """
        headers, data = self._make_up_data(code)

        token_url = self.ACCESS_TOKEN_URL

        resp = self._session.post(token_url, data=data, headers=headers)
        if not resp.ok:
            # network or apple server is down
            return None

        ret = resp.json()
        assert isinstance(ret, dict)
        if "error" in ret:
            return AppleSignInFailureRet(**ret)
        else:
            return AppleSignInSuccessRet(**ret)



from typing import Optional

from .base_args import BaseArgs


class TMallChaoShiArgs(BaseArgs):
    """
    天猫超市商品API：返回天猫超市商品列表，动态描述分≥4.6的商品列表，根据不同参数可返回天猫超市单件免邮商品。

    :doc https://www.zhetaoke.com/user/extend/extend_lingquan_tianmaochaoshi.aspx
    """

    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10001/api/api_all.ashx"

    page: int = 1
    page_size: int = 20
    sort: str = "new"
    cid: Optional[int] = None

    #  天猫超市商品是否单件免邮，值为1：天猫超市商品单件免邮，
    #  此字段只针对天猫超市店铺商品有效，其它店铺商品无效
    tianmaochaoshi2: Optional[int] = None

    tianmaochaoshi: int = 1



from .api_sync import DtkSyncApi
from .gen import *
from .test_shared import get_app_key_and_secret, get_id, get_goods_id, get_uland_url

g_sync_api: Optional[DtkSyncApi] = None


def get_sync_api() -> DtkSyncApi:
    global g_sync_api
    if g_sync_api is None:
        key, secret = get_app_key_and_secret()
        g_sync_api = DtkSyncApi(key, secret)
    return g_sync_api


def test_super_category():
    dtk = get_sync_api()
    ret = dtk.category_get_super_category()
    assert ret is not None


def test_gen_category_get_super_category():
    dtk = get_sync_api()
    ret = dtk.category_get_super_category()
    assert ret is not None


def test_goods_price_trend():
    dtk = get_sync_api()
    args = GoodsPriceTrendArgs(id=get_id())
    ret = dtk.goods_price_trend(args)
    assert ret is not None


def test_goods_dtk_search():
    dtk = get_sync_api()
    args = GoodsGetDtkSearchGoodsArgs(keyWords="手机", pageId=str(1), pageSize=str(10))
    ret = dtk.goods_get_dtk_search_goods(args)
    assert ret is not None


def test_tb_service_get_privilege_link():
    dtk = get_sync_api()
    args = TbServiceGetPrivilegeLinkArgs(goodsId=get_goods_id())
    ret = dtk.tb_service_get_privilege_link(args)
    assert ret is not None


def test_goods_get_ranking_list():
    dtk = get_sync_api()
    args = GoodsGetRankingListArgs(rankType=str(1))
    ret = dtk.goods_get_ranking_list(args)
    assert ret is not None


def test_goods_get_goods_details():
    dtk = get_sync_api()
    args = GoodsGetGoodsDetailsArgs(id=get_id())
    ret = dtk.goods_get_goods_details(args)
    assert ret is not None


def test_tb_service_get_brand_list():
    dtk = get_sync_api()
    args = TbServiceGetBrandListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.tb_service_get_brand_list(args)
    assert ret is not None
    print(ret)


def test_goods_nine_op_goods_list():
    dtk = get_sync_api()
    args = GoodsNineOpGoodsListArgs(pageId=str(1), pageSize=str(10), nineCid=str(1))
    ret = dtk.goods_nine_op_goods_list(args)
    assert ret is not None


def test_tb_service_get_tb_service():
    dtk = get_sync_api()
    args = TbServiceGetTbServiceArgs(pageNo=str(1), pageSize=str(10), keyWords="苹果")
    ret = dtk.tb_service_get_tb_service(args)
    assert ret is not None


def test_category_get_top100():
    dtk = get_sync_api()
    ret = dtk.category_get_top100()
    assert ret is not None


def test_goods_get_goods_list():
    dtk = get_sync_api()
    args = GoodsGetGoodsListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.goods_get_goods_list(args)
    assert ret is not None


def test_goods_list_super_goods():
    dtk = get_sync_api()
    args = GoodsListSuperGoodsArgs(
        pageId=str(1), pageSize=str(10), keyWords="iOS", type=str(0)
    )
    ret = dtk.goods_list_super_goods(args)
    assert ret is not None


def test_goods_list_similer_goods_by_open():
    dtk = get_sync_api()
    args = GoodsListSimilerGoodsByOpenArgs(id=str(get_id()))
    ret = dtk.goods_list_similer_goods_by_open(args)
    assert ret is not None


def test_goods_search_suggestion():
    dtk = get_sync_api()
    args = GoodsSearchSuggestionArgs(keyWords="手机", type=str(1))
    ret = dtk.goods_search_suggestion(args)
    assert ret is not None


def test_goods_activity_catalogue():
    dtk = get_sync_api()
    ret = dtk.goods_activity_catalogue()
    assert ret is not None


def test_goods_activity_goods_list():
    dtk = get_sync_api()
    # todo impl dtk.goods_activity_goods_list()


def test_goods_topic_catalogue():
    dtk = get_sync_api()
    ret = dtk.goods_topic_catalogue()
    assert ret is not None


def test_goods_topic_goods_list():
    dtk = get_sync_api()
    # args = GoodsTopicGoodsListArgs()
    # ret = dtk.goods_topic_goods_list()


def test_category_ddq_goods_list():
    dtk = get_sync_api()
    args = CategoryDdqGoodsListArgs()
    ret = dtk.category_ddq_goods_list(args)
    assert ret is not None


def test_tb_service_parse_taokouling():
    dtk = get_sync_api()
    args = TbServiceParseTaokoulingArgs(content="1￥uFkCciFmKQH￥/")
    ret = dtk.tb_service_parse_taokouling(args)
    assert ret is not None


def test_tb_service_creat_taokouling():
    dtk = get_sync_api()
    args = TbServiceCreatTaokoulingArgs(text="hello", url=get_uland_url())
    ret = dtk.tb_service_creat_taokouling(args)
    assert ret is not None


def test_goods_exclusive_goods_list():
    dtk = get_sync_api()
    args = GoodsExclusiveGoodsListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.goods_exclusive_goods_list(args)
    assert ret is not None


def test_goods_explosive_goods_list():
    """guess you like API"""
    dtk = get_sync_api()
    args = GoodsExplosiveGoodsListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.goods_explosive_goods_list(args)
    assert ret is not None


def test_delanys_brand_get_goods_list():
    dtk = get_sync_api()
    args = DelanysBrandGetGoodsListArgs(
        brandId="30844", pageId=str(1), pageSize=str(10)
    )
    out = dtk.delanys_brand_get_goods_list(args)
    assert out is not None
    print(out)



from .base_args import BaseArgs


class SuggestArgs(BaseArgs):
    """
    联想词 API

    :doc https://www.zhetaoke.com/user/extend/extend_lingquan_suggest.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/api_suggest.ashx"

    content: str



# 这个文件是由 json_code_gen_model.py 自动生成的 请不要修改

from typing import Optional

from pydantic import BaseModel

from . import fields


class ItemDetailV2Model(BaseModel):
    code: Optional[str] = fields.code_field
    type_one_id: Optional[str] = fields.type_one_id_field
    tao_id: Optional[str] = fields.tao_id_field
    title: Optional[str] = fields.title_field
    jianjie: Optional[str] = fields.jianjie_field
    pict_url: Optional[str] = fields.pict_url_field
    user_type: Optional[str] = fields.user_type_field
    seller_id: Optional[str] = fields.seller_id_field
    shop_dsr: Optional[str] = fields.shop_dsr_field
    volume: Optional[str] = fields.volume_field
    size: Optional[str] = fields.size_field
    quanhou_jiage: Optional[str] = fields.quanhou_jiage_field
    date_time_yongjin: Optional[str] = fields.date_time_yongjin_field
    tkrate3: Optional[str] = fields.tkrate3_field
    yongjin_type: Optional[str] = fields.yongjin_type_field
    coupon_id: Optional[str] = fields.coupon_id_field
    coupon_start_time: Optional[str] = fields.coupon_start_time_field
    coupon_end_time: Optional[str] = fields.coupon_end_time_field
    coupon_info_money: Optional[str] = fields.coupon_info_money_field
    coupon_total_count: Optional[str] = fields.coupon_total_count_field
    coupon_remain_count: Optional[str] = fields.coupon_remain_count_field
    coupon_info: Optional[str] = fields.coupon_info_field
    juhuasuan: Optional[str] = fields.juhuasuan_field
    taoqianggou: Optional[str] = fields.taoqianggou_field
    haitao: Optional[str] = fields.haitao_field
    jiyoujia: Optional[str] = fields.jiyoujia_field
    jinpaimaijia: Optional[str] = fields.jinpaimaijia_field
    pinpai: Optional[str] = fields.pinpai_field
    pinpai_name: Optional[str] = fields.pinpai_name_field
    yunfeixian: Optional[str] = fields.yunfeixian_field
    nick: Optional[str] = fields.nick_field
    small_images: Optional[str] = fields.small_images_field
    white_image: Optional[str] = fields.white_image_field
    tao_title: Optional[str] = fields.tao_title_field
    provcity: Optional[str] = fields.provcity_field
    shop_title: Optional[str] = fields.shop_title_field
    zhibo_url: Optional[str] = fields.zhibo_url_field
    sellCount: Optional[str] = fields.sellCount_field
    commentCount: Optional[str] = fields.commentCount_field
    favcount: Optional[str] = fields.favcount_field
    score1: Optional[str] = fields.score1_field
    score2: Optional[str] = fields.score2_field
    score3: Optional[str] = fields.score3_field
    creditLevel: Optional[str] = fields.creditLevel_field
    shopIcon: Optional[str] = fields.shopIcon_field
    pcDescContent: Optional[str] = fields.pcDescContent_field
    item_url: Optional[str] = fields.item_url_field
    category_id: Optional[str] = fields.category_id_field
    category_name: Optional[str] = fields.category_name_field
    level_one_category_id: Optional[str] = fields.level_one_category_id_field
    level_one_category_name: Optional[str] = fields.level_one_category_name_field
    tkfee3: Optional[str] = fields.tkfee3_field
    biaoqian: Optional[str] = fields.biaoqian_field
    tag: Optional[str] = fields.tag_field
    date_time: Optional[str] = fields.date_time_field
    presale_discount_fee_text: Optional[str] = fields.presale_discount_fee_text_field
    presale_tail_end_time: Optional[str] = fields.presale_tail_end_time_field
    presale_tail_start_time: Optional[str] = fields.presale_tail_start_time_field
    presale_end_time: Optional[str] = fields.presale_end_time_field
    presale_start_time: Optional[str] = fields.presale_start_time_field
    presale_deposit: Optional[str] = fields.presale_deposit_field
    min_commission_rate: Optional[str] = fields.min_commission_rate_field



from datetime import datetime, timedelta
from typing import Tuple

import jwt

from .dt import AppleConfig

__all__ = ["Shared"]


class Shared(object):
    """
    shared code between sync and async version
    """

    ACCESS_TOKEN_URL = "https://appleid.apple.com/auth/token"

    def __init__(self, config: AppleConfig):
        """
        :param config: 配置项目
        """
        self._config = config

    def _make_up_data(self, code: str) -> Tuple[dict, dict]:
        """
        组装需要发送的数据

        :param code: Apple SignIn 在客户端获取到的 授权码 (aka: authorizationCode)
        :return: (headers, data)
        """
        client_id = self._config.bundle_id
        client_secret = self._client_secret()

        headers = {"content-type": "application/x-www-form-urlencoded"}
        data = {
            "client_id": client_id,
            "client_secret": client_secret,
            "code": code,
            "grant_type": "authorization_code",
        }

        return headers, data

    def _client_secret(self) -> str:
        headers = {"key_id": self._config.key_id}

        payload = {
            "iss": self._config.team_id,
            "iat": datetime.utcnow(),
            "exp": datetime.utcnow() + timedelta(days=180),
            "aud": "https://appleid.apple.com",
            "sub": self._config.bundle_id,
        }

        private_key = self._config.private_key

        return jwt.encode(
            payload, private_key, algorithm="ES256", headers=headers
        ).decode("utf-8")



import json
from typing import Optional

import aiohttp
import structlog

from .auth_account_args import AuthAccountArgs
from .batch_item_args import BatchItemsArgs
from .batch_item_resp import BatchItemResp
from .channel_account_info_args import ChannelAccountInfoArgs
from .channel_id_list_args import ChannelIdListArgs
from .channel_invite_code_args import ChannelInviteCodeArgs
from .channel_save_record_args import ChannelSaveRecordArgs
from .item_detail_resp import ItemDetailResp
from .item_detail_v2_args import ItemDetailV2Args
from .item_detail_v2_resp import ItemDetailV2Resp
from .new_order_args import NewOrderArgs
from .tkl_create_args import TKLCreateArgs
from .tkl_create_resp import TKLCreateResp

__all__ = ["ZTK"]


class ZTK(object):
    """
    折淘客 开放平台 API
    """

    def __init__(self, ztk_sid: str, logger: structlog.stdlib.BoundLogger):
        """
        :param logger: 日志记录器
        """
        self._http: Optional[aiohttp.ClientSession] = None
        self._sid = ztk_sid
        self._logger = logger

    async def auth_account(self, args: AuthAccountArgs):
        """
        获取账户授权列表API接口
        """
        args.sid = await self._ztk_sid()

        url = await args.to_http_url()
        j = await self._do_query(url)
        return j

    async def batch_items(self, args: BatchItemsArgs) -> BatchItemResp:
        """
        批量获取 淘宝 信息

        :param args:
        :return:
        """
        url = await args.to_http_url()
        j = await self._do_query(url)
        return BatchItemResp(**j)

    async def channel_account_info(self, args: ChannelAccountInfoArgs):
        args.sid = await self._ztk_sid()

        url = await args.to_http_url()
        j = await self._do_query(url)
        return j

    async def channel_id_list(self, args: ChannelIdListArgs):
        args.sid = await self._ztk_sid()
        url = await args.to_http_url()
        j = await self._do_query(url)
        return j

    async def channel_invite_code(self, args: ChannelInviteCodeArgs):
        """
        淘宝客邀请码生成API：生成邀请码，然后让用户进行渠道备案，生成新的渠道ID
        """
        args.sid = await self._ztk_sid()

        url = await args.to_http_url()
        j = await self._do_query(url)
        return j

    async def channel_save_record(self, args: ChannelSaveRecordArgs):
        """
        淘宝客渠道备案API：用户进行渠道备案，生成新的渠道ID。
        """
        url = await args.to_http_url()
        j = await self._do_query(url)
        return j

    async def item_detail_v2(self, args: ItemDetailV2Args) -> ItemDetailV2Resp:
        args.sid = await self._ztk_sid()

        url = await args.to_http_url()
        j = await self._do_query(url)
        return ItemDetailV2Resp(**j)

    async def new_order(self, args: NewOrderArgs):
        """
        新订单获取
        """
        args.sid = await self._ztk_sid()

        url = await args.to_http_url()
        j = await self._do_query(url)
        return ItemDetailResp.from_ztk_resp(j)

    async def tkl_create(self, args: TKLCreateArgs) -> TKLCreateResp:
        """
        淘口令生成API：二合一链接、长链接、短链接等各种淘宝高佣链接，生成淘口令
        """
        args.sid = await self._ztk_sid()

        url = await args.to_http_url()
        j = await self._do_query(url)
        return TKLCreateResp(**j)

    async def do_query(self, url: str) -> dict:
        """
        这是给外部使用的函数

        :param url:
        :return:
        """
        return await self._do_query(url)

    async def _do_query(self, url: str) -> dict:
        if self._http is None:
            self._http = aiohttp.ClientSession()

        async with self._http.get(url) as result:
            text = await result.text()
            return json.loads(text)

    async def _ztk_sid(self) -> Optional[str]:
        """
        获取 折淘客的 sid
        """
        return self._sid



import os

import pytest
from structlog.stdlib import get_logger

from .gao_yong_args import GaoYongArgs
from .guess_you_like_args import GuessYouLikeArgs
from .search_args import SearchArgs
from .ztk_std import ZTKStd


def set_up_env():
    file = os.path.join(os.path.dirname(__file__), "../../dev.env")
    with open(file) as fp:
        lines = fp.readlines()
    for line in lines:
        line = line.strip()
        if line == "":
            continue
        if line.startswith("#"):
            continue
        parts = line.split("=")
        if len(parts) != 2:
            continue
        k, v = parts
        os.environ.setdefault(k, v)


def get_ztk_std() -> ZTKStd:
    set_up_env()

    logger = get_logger()
    sid = "49522"

    return ZTKStd(ztk_sid=sid, logger=logger)


def get_gao_yong_args(tao_id: str) -> GaoYongArgs:
    pid = "mm_1612410100_2210750041_111118250414"
    sid = "49522"
    return GaoYongArgs(pid=pid, num_iid=tao_id, sid=sid)


@pytest.mark.asyncio
async def test_guess_you_like_and_gao_yong():
    ztk = get_ztk_std()
    args = GuessYouLikeArgs()
    ret = await ztk.guess_you_like(args)
    assert ret is not None

    item = ret[0]
    args = get_gao_yong_args(item.tao_id)

    ret = await ztk.gao_yong(args)
    assert ret is not None
    print(ret)


@pytest.mark.asyncio
async def test_keyword():
    ztk = get_ztk_std()
    ret = await ztk.keyword()
    assert ret is not None
    print(ret)


@pytest.mark.asyncio
async def test_search_url():
    ztk = get_ztk_std()

    args = SearchArgs(
        q="https://detail.tmall.com/item.htm?id=627425639611&cm_id=140105335569ed55e27b"
    )

    data_list = await ztk.search(args)

    assert data_list is not None

    for item in data_list:
        args = get_gao_yong_args(item.tao_id)
        coupon_list = await ztk.gao_yong(args)
        print(coupon_list)
